"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.account_link_status_pb2
import google.ads.google_ads.v6.proto.enums.linked_account_type_pb2
import google.ads.google_ads.v6.proto.enums.mobile_app_vendor_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AccountLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ACCOUNT_LINK_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    THIRD_PARTY_APP_ANALYTICS_FIELD_NUMBER: builtins.int
    DATA_PARTNER_FIELD_NUMBER: builtins.int
    GOOGLE_ADS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    account_link_id: builtins.int = ...
    status: google.ads.google_ads.v6.proto.enums.account_link_status_pb2.AccountLinkStatusEnum.AccountLinkStatus.V = (
        ...
    )
    type: google.ads.google_ads.v6.proto.enums.linked_account_type_pb2.LinkedAccountTypeEnum.LinkedAccountType.V = (
        ...
    )
    @property
    def third_party_app_analytics(
        self,
    ) -> global___ThirdPartyAppAnalyticsLinkIdentifier: ...
    @property
    def data_partner(self) -> global___DataPartnerLinkIdentifier: ...
    @property
    def google_ads(self) -> global___GoogleAdsLinkIdentifier: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        account_link_id: builtins.int = ...,
        status: google.ads.google_ads.v6.proto.enums.account_link_status_pb2.AccountLinkStatusEnum.AccountLinkStatus.V = ...,
        type: google.ads.google_ads.v6.proto.enums.linked_account_type_pb2.LinkedAccountTypeEnum.LinkedAccountType.V = ...,
        third_party_app_analytics: typing.Optional[
            global___ThirdPartyAppAnalyticsLinkIdentifier
        ] = ...,
        data_partner: typing.Optional[global___DataPartnerLinkIdentifier] = ...,
        google_ads: typing.Optional[global___GoogleAdsLinkIdentifier] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_account_link_id",
            b"_account_link_id",
            "account_link_id",
            b"account_link_id",
            "data_partner",
            b"data_partner",
            "google_ads",
            b"google_ads",
            "linked_account",
            b"linked_account",
            "third_party_app_analytics",
            b"third_party_app_analytics",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_account_link_id",
            b"_account_link_id",
            "account_link_id",
            b"account_link_id",
            "data_partner",
            b"data_partner",
            "google_ads",
            b"google_ads",
            "linked_account",
            b"linked_account",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "third_party_app_analytics",
            b"third_party_app_analytics",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_account_link_id", b"_account_link_id"],
    ) -> typing_extensions.Literal["account_link_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["linked_account", b"linked_account"],
    ) -> typing_extensions.Literal[
        "third_party_app_analytics", "data_partner", "google_ads"
    ]: ...

global___AccountLink = AccountLink

class ThirdPartyAppAnalyticsLinkIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    APP_ANALYTICS_PROVIDER_ID_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    APP_VENDOR_FIELD_NUMBER: builtins.int
    app_analytics_provider_id: builtins.int = ...
    app_id: typing.Text = ...
    app_vendor: google.ads.google_ads.v6.proto.enums.mobile_app_vendor_pb2.MobileAppVendorEnum.MobileAppVendor.V = (
        ...
    )
    def __init__(
        self,
        *,
        app_analytics_provider_id: builtins.int = ...,
        app_id: typing.Text = ...,
        app_vendor: google.ads.google_ads.v6.proto.enums.mobile_app_vendor_pb2.MobileAppVendorEnum.MobileAppVendor.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_app_analytics_provider_id",
            b"_app_analytics_provider_id",
            "_app_id",
            b"_app_id",
            "app_analytics_provider_id",
            b"app_analytics_provider_id",
            "app_id",
            b"app_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_app_analytics_provider_id",
            b"_app_analytics_provider_id",
            "_app_id",
            b"_app_id",
            "app_analytics_provider_id",
            b"app_analytics_provider_id",
            "app_id",
            b"app_id",
            "app_vendor",
            b"app_vendor",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_app_analytics_provider_id", b"_app_analytics_provider_id"
        ],
    ) -> typing_extensions.Literal["app_analytics_provider_id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_app_id", b"_app_id"]
    ) -> typing_extensions.Literal["app_id"]: ...

global___ThirdPartyAppAnalyticsLinkIdentifier = ThirdPartyAppAnalyticsLinkIdentifier

class DataPartnerLinkIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_PARTNER_ID_FIELD_NUMBER: builtins.int
    data_partner_id: builtins.int = ...
    def __init__(
        self,
        *,
        data_partner_id: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_data_partner_id",
            b"_data_partner_id",
            "data_partner_id",
            b"data_partner_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_data_partner_id",
            b"_data_partner_id",
            "data_partner_id",
            b"data_partner_id",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_data_partner_id", b"_data_partner_id"],
    ) -> typing_extensions.Literal["data_partner_id"]: ...

global___DataPartnerLinkIdentifier = DataPartnerLinkIdentifier

class GoogleAdsLinkIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_FIELD_NUMBER: builtins.int
    customer: typing.Text = ...
    def __init__(
        self,
        *,
        customer: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_customer", b"_customer", "customer", b"customer"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_customer", b"_customer", "customer", b"customer"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_customer", b"_customer"]
    ) -> typing_extensions.Literal["customer"]: ...

global___GoogleAdsLinkIdentifier = GoogleAdsLinkIdentifier



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedAttributeTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedAttributeType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FeedAttributeType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedAttributeTypeEnum.FeedAttributeType.V(0)
        UNKNOWN = FeedAttributeTypeEnum.FeedAttributeType.V(1)
        INT64 = FeedAttributeTypeEnum.FeedAttributeType.V(2)
        DOUBLE = FeedAttributeTypeEnum.FeedAttributeType.V(3)
        STRING = FeedAttributeTypeEnum.FeedAttributeType.V(4)
        BOOLEAN = FeedAttributeTypeEnum.FeedAttributeType.V(5)
        URL = FeedAttributeTypeEnum.FeedAttributeType.V(6)
        DATE_TIME = FeedAttributeTypeEnum.FeedAttributeType.V(7)
        INT64_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(8)
        DOUBLE_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(9)
        STRING_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(10)
        BOOLEAN_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(11)
        URL_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(12)
        DATE_TIME_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(13)
        PRICE = FeedAttributeTypeEnum.FeedAttributeType.V(14)
    class FeedAttributeType(metaclass=_FeedAttributeType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedAttributeTypeEnum.FeedAttributeType.V(0)
    UNKNOWN = FeedAttributeTypeEnum.FeedAttributeType.V(1)
    INT64 = FeedAttributeTypeEnum.FeedAttributeType.V(2)
    DOUBLE = FeedAttributeTypeEnum.FeedAttributeType.V(3)
    STRING = FeedAttributeTypeEnum.FeedAttributeType.V(4)
    BOOLEAN = FeedAttributeTypeEnum.FeedAttributeType.V(5)
    URL = FeedAttributeTypeEnum.FeedAttributeType.V(6)
    DATE_TIME = FeedAttributeTypeEnum.FeedAttributeType.V(7)
    INT64_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(8)
    DOUBLE_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(9)
    STRING_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(10)
    BOOLEAN_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(11)
    URL_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(12)
    DATE_TIME_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(13)
    PRICE = FeedAttributeTypeEnum.FeedAttributeType.V(14)
    def __init__(
        self,
    ) -> None: ...

global___FeedAttributeTypeEnum = FeedAttributeTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.interaction_event_type_pb2
import google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Metrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ABSOLUTE_TOP_IMPRESSION_PERCENTAGE_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_CPM_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_CTR_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_IMPRESSIONS_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_MEASURABILITY_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_MEASURABLE_COST_MICROS_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_MEASURABLE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_VIEWABILITY_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_INTERACTIONS_RATE_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_VALUE_BY_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_BY_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_VALUE_PER_COST_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_CLICK_TO_CALL_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_DIRECTIONS_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_INTERACTIONS_VALUE_PER_INTERACTION_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_MENU_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_ORDER_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_OTHER_ENGAGEMENT_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_STORE_VISIT_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_STORE_WEBSITE_FIELD_NUMBER: builtins.int
    AVERAGE_COST_FIELD_NUMBER: builtins.int
    AVERAGE_CPC_FIELD_NUMBER: builtins.int
    AVERAGE_CPE_FIELD_NUMBER: builtins.int
    AVERAGE_CPM_FIELD_NUMBER: builtins.int
    AVERAGE_CPV_FIELD_NUMBER: builtins.int
    AVERAGE_PAGE_VIEWS_FIELD_NUMBER: builtins.int
    AVERAGE_TIME_ON_SITE_FIELD_NUMBER: builtins.int
    BENCHMARK_AVERAGE_MAX_CPC_FIELD_NUMBER: builtins.int
    BENCHMARK_CTR_FIELD_NUMBER: builtins.int
    BOUNCE_RATE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COMBINED_CLICKS_FIELD_NUMBER: builtins.int
    COMBINED_CLICKS_PER_QUERY_FIELD_NUMBER: builtins.int
    COMBINED_QUERIES_FIELD_NUMBER: builtins.int
    CONTENT_BUDGET_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    CONTENT_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    CONVERSION_LAST_RECEIVED_REQUEST_DATE_TIME_FIELD_NUMBER: builtins.int
    CONVERSION_LAST_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    CONTENT_RANK_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    CONVERSIONS_FROM_INTERACTIONS_RATE_FIELD_NUMBER: builtins.int
    CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CONVERSIONS_VALUE_BY_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    CONVERSIONS_VALUE_PER_COST_FIELD_NUMBER: builtins.int
    CONVERSIONS_FROM_INTERACTIONS_VALUE_PER_INTERACTION_FIELD_NUMBER: builtins.int
    CONVERSIONS_FIELD_NUMBER: builtins.int
    CONVERSIONS_BY_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    COST_PER_ALL_CONVERSIONS_FIELD_NUMBER: builtins.int
    COST_PER_CONVERSION_FIELD_NUMBER: builtins.int
    COST_PER_CURRENT_MODEL_ATTRIBUTED_CONVERSION_FIELD_NUMBER: builtins.int
    CROSS_DEVICE_CONVERSIONS_FIELD_NUMBER: builtins.int
    CTR_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_FROM_INTERACTIONS_RATE_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_FROM_INTERACTIONS_VALUE_PER_INTERACTION_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_VALUE_PER_COST_FIELD_NUMBER: builtins.int
    ENGAGEMENT_RATE_FIELD_NUMBER: builtins.int
    ENGAGEMENTS_FIELD_NUMBER: builtins.int
    HOTEL_AVERAGE_LEAD_VALUE_MICROS_FIELD_NUMBER: builtins.int
    HOTEL_PRICE_DIFFERENCE_PERCENTAGE_FIELD_NUMBER: builtins.int
    HOTEL_ELIGIBLE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    HISTORICAL_CREATIVE_QUALITY_SCORE_FIELD_NUMBER: builtins.int
    HISTORICAL_LANDING_PAGE_QUALITY_SCORE_FIELD_NUMBER: builtins.int
    HISTORICAL_QUALITY_SCORE_FIELD_NUMBER: builtins.int
    HISTORICAL_SEARCH_PREDICTED_CTR_FIELD_NUMBER: builtins.int
    GMAIL_FORWARDS_FIELD_NUMBER: builtins.int
    GMAIL_SAVES_FIELD_NUMBER: builtins.int
    GMAIL_SECONDARY_CLICKS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FROM_STORE_REACH_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    INTERACTION_RATE_FIELD_NUMBER: builtins.int
    INTERACTIONS_FIELD_NUMBER: builtins.int
    INTERACTION_EVENT_TYPES_FIELD_NUMBER: builtins.int
    INVALID_CLICK_RATE_FIELD_NUMBER: builtins.int
    INVALID_CLICKS_FIELD_NUMBER: builtins.int
    MESSAGE_CHATS_FIELD_NUMBER: builtins.int
    MESSAGE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    MESSAGE_CHAT_RATE_FIELD_NUMBER: builtins.int
    MOBILE_FRIENDLY_CLICKS_PERCENTAGE_FIELD_NUMBER: builtins.int
    ORGANIC_CLICKS_FIELD_NUMBER: builtins.int
    ORGANIC_CLICKS_PER_QUERY_FIELD_NUMBER: builtins.int
    ORGANIC_IMPRESSIONS_FIELD_NUMBER: builtins.int
    ORGANIC_IMPRESSIONS_PER_QUERY_FIELD_NUMBER: builtins.int
    ORGANIC_QUERIES_FIELD_NUMBER: builtins.int
    PERCENT_NEW_VISITORS_FIELD_NUMBER: builtins.int
    PHONE_CALLS_FIELD_NUMBER: builtins.int
    PHONE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    PHONE_THROUGH_RATE_FIELD_NUMBER: builtins.int
    RELATIVE_CTR_FIELD_NUMBER: builtins.int
    SEARCH_ABSOLUTE_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_BUDGET_LOST_ABSOLUTE_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_BUDGET_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_BUDGET_LOST_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_CLICK_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_EXACT_MATCH_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_RANK_LOST_ABSOLUTE_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_RANK_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_RANK_LOST_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SPEED_SCORE_FIELD_NUMBER: builtins.int
    TOP_IMPRESSION_PERCENTAGE_FIELD_NUMBER: builtins.int
    VALID_ACCELERATED_MOBILE_PAGES_CLICKS_PERCENTAGE_FIELD_NUMBER: builtins.int
    VALUE_PER_ALL_CONVERSIONS_FIELD_NUMBER: builtins.int
    VALUE_PER_ALL_CONVERSIONS_BY_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    VALUE_PER_CONVERSION_FIELD_NUMBER: builtins.int
    VALUE_PER_CONVERSIONS_BY_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    VALUE_PER_CURRENT_MODEL_ATTRIBUTED_CONVERSION_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_P100_RATE_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_P25_RATE_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_P50_RATE_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_P75_RATE_FIELD_NUMBER: builtins.int
    VIDEO_VIEW_RATE_FIELD_NUMBER: builtins.int
    VIDEO_VIEWS_FIELD_NUMBER: builtins.int
    VIEW_THROUGH_CONVERSIONS_FIELD_NUMBER: builtins.int
    absolute_top_impression_percentage: builtins.float = ...
    active_view_cpm: builtins.float = ...
    active_view_ctr: builtins.float = ...
    active_view_impressions: builtins.int = ...
    active_view_measurability: builtins.float = ...
    active_view_measurable_cost_micros: builtins.int = ...
    active_view_measurable_impressions: builtins.int = ...
    active_view_viewability: builtins.float = ...
    all_conversions_from_interactions_rate: builtins.float = ...
    all_conversions_value: builtins.float = ...
    all_conversions_value_by_conversion_date: builtins.float = ...
    all_conversions: builtins.float = ...
    all_conversions_by_conversion_date: builtins.float = ...
    all_conversions_value_per_cost: builtins.float = ...
    all_conversions_from_click_to_call: builtins.float = ...
    all_conversions_from_directions: builtins.float = ...
    all_conversions_from_interactions_value_per_interaction: builtins.float = ...
    all_conversions_from_menu: builtins.float = ...
    all_conversions_from_order: builtins.float = ...
    all_conversions_from_other_engagement: builtins.float = ...
    all_conversions_from_store_visit: builtins.float = ...
    all_conversions_from_store_website: builtins.float = ...
    average_cost: builtins.float = ...
    average_cpc: builtins.float = ...
    average_cpe: builtins.float = ...
    average_cpm: builtins.float = ...
    average_cpv: builtins.float = ...
    average_page_views: builtins.float = ...
    average_time_on_site: builtins.float = ...
    benchmark_average_max_cpc: builtins.float = ...
    benchmark_ctr: builtins.float = ...
    bounce_rate: builtins.float = ...
    clicks: builtins.int = ...
    combined_clicks: builtins.int = ...
    combined_clicks_per_query: builtins.float = ...
    combined_queries: builtins.int = ...
    content_budget_lost_impression_share: builtins.float = ...
    content_impression_share: builtins.float = ...
    conversion_last_received_request_date_time: typing.Text = ...
    conversion_last_conversion_date: typing.Text = ...
    content_rank_lost_impression_share: builtins.float = ...
    conversions_from_interactions_rate: builtins.float = ...
    conversions_value: builtins.float = ...
    conversions_value_by_conversion_date: builtins.float = ...
    conversions_value_per_cost: builtins.float = ...
    conversions_from_interactions_value_per_interaction: builtins.float = ...
    conversions: builtins.float = ...
    conversions_by_conversion_date: builtins.float = ...
    cost_micros: builtins.int = ...
    cost_per_all_conversions: builtins.float = ...
    cost_per_conversion: builtins.float = ...
    cost_per_current_model_attributed_conversion: builtins.float = ...
    cross_device_conversions: builtins.float = ...
    ctr: builtins.float = ...
    current_model_attributed_conversions: builtins.float = ...
    current_model_attributed_conversions_from_interactions_rate: builtins.float = ...
    current_model_attributed_conversions_from_interactions_value_per_interaction: builtins.float = (
        ...
    )
    current_model_attributed_conversions_value: builtins.float = ...
    current_model_attributed_conversions_value_per_cost: builtins.float = ...
    engagement_rate: builtins.float = ...
    engagements: builtins.int = ...
    hotel_average_lead_value_micros: builtins.float = ...
    hotel_price_difference_percentage: builtins.float = ...
    hotel_eligible_impressions: builtins.int = ...
    historical_creative_quality_score: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = (
        ...
    )
    historical_landing_page_quality_score: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = (
        ...
    )
    historical_quality_score: builtins.int = ...
    historical_search_predicted_ctr: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = (
        ...
    )
    gmail_forwards: builtins.int = ...
    gmail_saves: builtins.int = ...
    gmail_secondary_clicks: builtins.int = ...
    impressions_from_store_reach: builtins.int = ...
    impressions: builtins.int = ...
    interaction_rate: builtins.float = ...
    interactions: builtins.int = ...
    interaction_event_types: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        google.ads.google_ads.v6.proto.enums.interaction_event_type_pb2.InteractionEventTypeEnum.InteractionEventType.V
    ] = ...
    invalid_click_rate: builtins.float = ...
    invalid_clicks: builtins.int = ...
    message_chats: builtins.int = ...
    message_impressions: builtins.int = ...
    message_chat_rate: builtins.float = ...
    mobile_friendly_clicks_percentage: builtins.float = ...
    organic_clicks: builtins.int = ...
    organic_clicks_per_query: builtins.float = ...
    organic_impressions: builtins.int = ...
    organic_impressions_per_query: builtins.float = ...
    organic_queries: builtins.int = ...
    percent_new_visitors: builtins.float = ...
    phone_calls: builtins.int = ...
    phone_impressions: builtins.int = ...
    phone_through_rate: builtins.float = ...
    relative_ctr: builtins.float = ...
    search_absolute_top_impression_share: builtins.float = ...
    search_budget_lost_absolute_top_impression_share: builtins.float = ...
    search_budget_lost_impression_share: builtins.float = ...
    search_budget_lost_top_impression_share: builtins.float = ...
    search_click_share: builtins.float = ...
    search_exact_match_impression_share: builtins.float = ...
    search_impression_share: builtins.float = ...
    search_rank_lost_absolute_top_impression_share: builtins.float = ...
    search_rank_lost_impression_share: builtins.float = ...
    search_rank_lost_top_impression_share: builtins.float = ...
    search_top_impression_share: builtins.float = ...
    speed_score: builtins.int = ...
    top_impression_percentage: builtins.float = ...
    valid_accelerated_mobile_pages_clicks_percentage: builtins.float = ...
    value_per_all_conversions: builtins.float = ...
    value_per_all_conversions_by_conversion_date: builtins.float = ...
    value_per_conversion: builtins.float = ...
    value_per_conversions_by_conversion_date: builtins.float = ...
    value_per_current_model_attributed_conversion: builtins.float = ...
    video_quartile_p100_rate: builtins.float = ...
    video_quartile_p25_rate: builtins.float = ...
    video_quartile_p50_rate: builtins.float = ...
    video_quartile_p75_rate: builtins.float = ...
    video_view_rate: builtins.float = ...
    video_views: builtins.int = ...
    view_through_conversions: builtins.int = ...
    def __init__(
        self,
        *,
        absolute_top_impression_percentage: builtins.float = ...,
        active_view_cpm: builtins.float = ...,
        active_view_ctr: builtins.float = ...,
        active_view_impressions: builtins.int = ...,
        active_view_measurability: builtins.float = ...,
        active_view_measurable_cost_micros: builtins.int = ...,
        active_view_measurable_impressions: builtins.int = ...,
        active_view_viewability: builtins.float = ...,
        all_conversions_from_interactions_rate: builtins.float = ...,
        all_conversions_value: builtins.float = ...,
        all_conversions_value_by_conversion_date: builtins.float = ...,
        all_conversions: builtins.float = ...,
        all_conversions_by_conversion_date: builtins.float = ...,
        all_conversions_value_per_cost: builtins.float = ...,
        all_conversions_from_click_to_call: builtins.float = ...,
        all_conversions_from_directions: builtins.float = ...,
        all_conversions_from_interactions_value_per_interaction: builtins.float = ...,
        all_conversions_from_menu: builtins.float = ...,
        all_conversions_from_order: builtins.float = ...,
        all_conversions_from_other_engagement: builtins.float = ...,
        all_conversions_from_store_visit: builtins.float = ...,
        all_conversions_from_store_website: builtins.float = ...,
        average_cost: builtins.float = ...,
        average_cpc: builtins.float = ...,
        average_cpe: builtins.float = ...,
        average_cpm: builtins.float = ...,
        average_cpv: builtins.float = ...,
        average_page_views: builtins.float = ...,
        average_time_on_site: builtins.float = ...,
        benchmark_average_max_cpc: builtins.float = ...,
        benchmark_ctr: builtins.float = ...,
        bounce_rate: builtins.float = ...,
        clicks: builtins.int = ...,
        combined_clicks: builtins.int = ...,
        combined_clicks_per_query: builtins.float = ...,
        combined_queries: builtins.int = ...,
        content_budget_lost_impression_share: builtins.float = ...,
        content_impression_share: builtins.float = ...,
        conversion_last_received_request_date_time: typing.Text = ...,
        conversion_last_conversion_date: typing.Text = ...,
        content_rank_lost_impression_share: builtins.float = ...,
        conversions_from_interactions_rate: builtins.float = ...,
        conversions_value: builtins.float = ...,
        conversions_value_by_conversion_date: builtins.float = ...,
        conversions_value_per_cost: builtins.float = ...,
        conversions_from_interactions_value_per_interaction: builtins.float = ...,
        conversions: builtins.float = ...,
        conversions_by_conversion_date: builtins.float = ...,
        cost_micros: builtins.int = ...,
        cost_per_all_conversions: builtins.float = ...,
        cost_per_conversion: builtins.float = ...,
        cost_per_current_model_attributed_conversion: builtins.float = ...,
        cross_device_conversions: builtins.float = ...,
        ctr: builtins.float = ...,
        current_model_attributed_conversions: builtins.float = ...,
        current_model_attributed_conversions_from_interactions_rate: builtins.float = ...,
        current_model_attributed_conversions_from_interactions_value_per_interaction: builtins.float = ...,
        current_model_attributed_conversions_value: builtins.float = ...,
        current_model_attributed_conversions_value_per_cost: builtins.float = ...,
        engagement_rate: builtins.float = ...,
        engagements: builtins.int = ...,
        hotel_average_lead_value_micros: builtins.float = ...,
        hotel_price_difference_percentage: builtins.float = ...,
        hotel_eligible_impressions: builtins.int = ...,
        historical_creative_quality_score: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = ...,
        historical_landing_page_quality_score: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = ...,
        historical_quality_score: builtins.int = ...,
        historical_search_predicted_ctr: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = ...,
        gmail_forwards: builtins.int = ...,
        gmail_saves: builtins.int = ...,
        gmail_secondary_clicks: builtins.int = ...,
        impressions_from_store_reach: builtins.int = ...,
        impressions: builtins.int = ...,
        interaction_rate: builtins.float = ...,
        interactions: builtins.int = ...,
        interaction_event_types: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.enums.interaction_event_type_pb2.InteractionEventTypeEnum.InteractionEventType.V
            ]
        ] = ...,
        invalid_click_rate: builtins.float = ...,
        invalid_clicks: builtins.int = ...,
        message_chats: builtins.int = ...,
        message_impressions: builtins.int = ...,
        message_chat_rate: builtins.float = ...,
        mobile_friendly_clicks_percentage: builtins.float = ...,
        organic_clicks: builtins.int = ...,
        organic_clicks_per_query: builtins.float = ...,
        organic_impressions: builtins.int = ...,
        organic_impressions_per_query: builtins.float = ...,
        organic_queries: builtins.int = ...,
        percent_new_visitors: builtins.float = ...,
        phone_calls: builtins.int = ...,
        phone_impressions: builtins.int = ...,
        phone_through_rate: builtins.float = ...,
        relative_ctr: builtins.float = ...,
        search_absolute_top_impression_share: builtins.float = ...,
        search_budget_lost_absolute_top_impression_share: builtins.float = ...,
        search_budget_lost_impression_share: builtins.float = ...,
        search_budget_lost_top_impression_share: builtins.float = ...,
        search_click_share: builtins.float = ...,
        search_exact_match_impression_share: builtins.float = ...,
        search_impression_share: builtins.float = ...,
        search_rank_lost_absolute_top_impression_share: builtins.float = ...,
        search_rank_lost_impression_share: builtins.float = ...,
        search_rank_lost_top_impression_share: builtins.float = ...,
        search_top_impression_share: builtins.float = ...,
        speed_score: builtins.int = ...,
        top_impression_percentage: builtins.float = ...,
        valid_accelerated_mobile_pages_clicks_percentage: builtins.float = ...,
        value_per_all_conversions: builtins.float = ...,
        value_per_all_conversions_by_conversion_date: builtins.float = ...,
        value_per_conversion: builtins.float = ...,
        value_per_conversions_by_conversion_date: builtins.float = ...,
        value_per_current_model_attributed_conversion: builtins.float = ...,
        video_quartile_p100_rate: builtins.float = ...,
        video_quartile_p25_rate: builtins.float = ...,
        video_quartile_p50_rate: builtins.float = ...,
        video_quartile_p75_rate: builtins.float = ...,
        video_view_rate: builtins.float = ...,
        video_views: builtins.int = ...,
        view_through_conversions: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_absolute_top_impression_percentage",
            b"_absolute_top_impression_percentage",
            "_active_view_cpm",
            b"_active_view_cpm",
            "_active_view_ctr",
            b"_active_view_ctr",
            "_active_view_impressions",
            b"_active_view_impressions",
            "_active_view_measurability",
            b"_active_view_measurability",
            "_active_view_measurable_cost_micros",
            b"_active_view_measurable_cost_micros",
            "_active_view_measurable_impressions",
            b"_active_view_measurable_impressions",
            "_active_view_viewability",
            b"_active_view_viewability",
            "_all_conversions",
            b"_all_conversions",
            "_all_conversions_from_click_to_call",
            b"_all_conversions_from_click_to_call",
            "_all_conversions_from_directions",
            b"_all_conversions_from_directions",
            "_all_conversions_from_interactions_rate",
            b"_all_conversions_from_interactions_rate",
            "_all_conversions_from_interactions_value_per_interaction",
            b"_all_conversions_from_interactions_value_per_interaction",
            "_all_conversions_from_menu",
            b"_all_conversions_from_menu",
            "_all_conversions_from_order",
            b"_all_conversions_from_order",
            "_all_conversions_from_other_engagement",
            b"_all_conversions_from_other_engagement",
            "_all_conversions_from_store_visit",
            b"_all_conversions_from_store_visit",
            "_all_conversions_from_store_website",
            b"_all_conversions_from_store_website",
            "_all_conversions_value",
            b"_all_conversions_value",
            "_all_conversions_value_per_cost",
            b"_all_conversions_value_per_cost",
            "_average_cost",
            b"_average_cost",
            "_average_cpc",
            b"_average_cpc",
            "_average_cpe",
            b"_average_cpe",
            "_average_cpm",
            b"_average_cpm",
            "_average_cpv",
            b"_average_cpv",
            "_average_page_views",
            b"_average_page_views",
            "_average_time_on_site",
            b"_average_time_on_site",
            "_benchmark_average_max_cpc",
            b"_benchmark_average_max_cpc",
            "_benchmark_ctr",
            b"_benchmark_ctr",
            "_bounce_rate",
            b"_bounce_rate",
            "_clicks",
            b"_clicks",
            "_combined_clicks",
            b"_combined_clicks",
            "_combined_clicks_per_query",
            b"_combined_clicks_per_query",
            "_combined_queries",
            b"_combined_queries",
            "_content_budget_lost_impression_share",
            b"_content_budget_lost_impression_share",
            "_content_impression_share",
            b"_content_impression_share",
            "_content_rank_lost_impression_share",
            b"_content_rank_lost_impression_share",
            "_conversion_last_conversion_date",
            b"_conversion_last_conversion_date",
            "_conversion_last_received_request_date_time",
            b"_conversion_last_received_request_date_time",
            "_conversions",
            b"_conversions",
            "_conversions_from_interactions_rate",
            b"_conversions_from_interactions_rate",
            "_conversions_from_interactions_value_per_interaction",
            b"_conversions_from_interactions_value_per_interaction",
            "_conversions_value",
            b"_conversions_value",
            "_conversions_value_per_cost",
            b"_conversions_value_per_cost",
            "_cost_micros",
            b"_cost_micros",
            "_cost_per_all_conversions",
            b"_cost_per_all_conversions",
            "_cost_per_conversion",
            b"_cost_per_conversion",
            "_cost_per_current_model_attributed_conversion",
            b"_cost_per_current_model_attributed_conversion",
            "_cross_device_conversions",
            b"_cross_device_conversions",
            "_ctr",
            b"_ctr",
            "_current_model_attributed_conversions",
            b"_current_model_attributed_conversions",
            "_current_model_attributed_conversions_from_interactions_rate",
            b"_current_model_attributed_conversions_from_interactions_rate",
            "_current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"_current_model_attributed_conversions_from_interactions_value_per_interaction",
            "_current_model_attributed_conversions_value",
            b"_current_model_attributed_conversions_value",
            "_current_model_attributed_conversions_value_per_cost",
            b"_current_model_attributed_conversions_value_per_cost",
            "_engagement_rate",
            b"_engagement_rate",
            "_engagements",
            b"_engagements",
            "_gmail_forwards",
            b"_gmail_forwards",
            "_gmail_saves",
            b"_gmail_saves",
            "_gmail_secondary_clicks",
            b"_gmail_secondary_clicks",
            "_historical_quality_score",
            b"_historical_quality_score",
            "_hotel_average_lead_value_micros",
            b"_hotel_average_lead_value_micros",
            "_hotel_eligible_impressions",
            b"_hotel_eligible_impressions",
            "_hotel_price_difference_percentage",
            b"_hotel_price_difference_percentage",
            "_impressions",
            b"_impressions",
            "_impressions_from_store_reach",
            b"_impressions_from_store_reach",
            "_interaction_rate",
            b"_interaction_rate",
            "_interactions",
            b"_interactions",
            "_invalid_click_rate",
            b"_invalid_click_rate",
            "_invalid_clicks",
            b"_invalid_clicks",
            "_message_chat_rate",
            b"_message_chat_rate",
            "_message_chats",
            b"_message_chats",
            "_message_impressions",
            b"_message_impressions",
            "_mobile_friendly_clicks_percentage",
            b"_mobile_friendly_clicks_percentage",
            "_organic_clicks",
            b"_organic_clicks",
            "_organic_clicks_per_query",
            b"_organic_clicks_per_query",
            "_organic_impressions",
            b"_organic_impressions",
            "_organic_impressions_per_query",
            b"_organic_impressions_per_query",
            "_organic_queries",
            b"_organic_queries",
            "_percent_new_visitors",
            b"_percent_new_visitors",
            "_phone_calls",
            b"_phone_calls",
            "_phone_impressions",
            b"_phone_impressions",
            "_phone_through_rate",
            b"_phone_through_rate",
            "_relative_ctr",
            b"_relative_ctr",
            "_search_absolute_top_impression_share",
            b"_search_absolute_top_impression_share",
            "_search_budget_lost_absolute_top_impression_share",
            b"_search_budget_lost_absolute_top_impression_share",
            "_search_budget_lost_impression_share",
            b"_search_budget_lost_impression_share",
            "_search_budget_lost_top_impression_share",
            b"_search_budget_lost_top_impression_share",
            "_search_click_share",
            b"_search_click_share",
            "_search_exact_match_impression_share",
            b"_search_exact_match_impression_share",
            "_search_impression_share",
            b"_search_impression_share",
            "_search_rank_lost_absolute_top_impression_share",
            b"_search_rank_lost_absolute_top_impression_share",
            "_search_rank_lost_impression_share",
            b"_search_rank_lost_impression_share",
            "_search_rank_lost_top_impression_share",
            b"_search_rank_lost_top_impression_share",
            "_search_top_impression_share",
            b"_search_top_impression_share",
            "_speed_score",
            b"_speed_score",
            "_top_impression_percentage",
            b"_top_impression_percentage",
            "_valid_accelerated_mobile_pages_clicks_percentage",
            b"_valid_accelerated_mobile_pages_clicks_percentage",
            "_value_per_all_conversions",
            b"_value_per_all_conversions",
            "_value_per_all_conversions_by_conversion_date",
            b"_value_per_all_conversions_by_conversion_date",
            "_value_per_conversion",
            b"_value_per_conversion",
            "_value_per_conversions_by_conversion_date",
            b"_value_per_conversions_by_conversion_date",
            "_value_per_current_model_attributed_conversion",
            b"_value_per_current_model_attributed_conversion",
            "_video_quartile_p100_rate",
            b"_video_quartile_p100_rate",
            "_video_quartile_p25_rate",
            b"_video_quartile_p25_rate",
            "_video_quartile_p50_rate",
            b"_video_quartile_p50_rate",
            "_video_quartile_p75_rate",
            b"_video_quartile_p75_rate",
            "_video_view_rate",
            b"_video_view_rate",
            "_video_views",
            b"_video_views",
            "_view_through_conversions",
            b"_view_through_conversions",
            "absolute_top_impression_percentage",
            b"absolute_top_impression_percentage",
            "active_view_cpm",
            b"active_view_cpm",
            "active_view_ctr",
            b"active_view_ctr",
            "active_view_impressions",
            b"active_view_impressions",
            "active_view_measurability",
            b"active_view_measurability",
            "active_view_measurable_cost_micros",
            b"active_view_measurable_cost_micros",
            "active_view_measurable_impressions",
            b"active_view_measurable_impressions",
            "active_view_viewability",
            b"active_view_viewability",
            "all_conversions",
            b"all_conversions",
            "all_conversions_from_click_to_call",
            b"all_conversions_from_click_to_call",
            "all_conversions_from_directions",
            b"all_conversions_from_directions",
            "all_conversions_from_interactions_rate",
            b"all_conversions_from_interactions_rate",
            "all_conversions_from_interactions_value_per_interaction",
            b"all_conversions_from_interactions_value_per_interaction",
            "all_conversions_from_menu",
            b"all_conversions_from_menu",
            "all_conversions_from_order",
            b"all_conversions_from_order",
            "all_conversions_from_other_engagement",
            b"all_conversions_from_other_engagement",
            "all_conversions_from_store_visit",
            b"all_conversions_from_store_visit",
            "all_conversions_from_store_website",
            b"all_conversions_from_store_website",
            "all_conversions_value",
            b"all_conversions_value",
            "all_conversions_value_per_cost",
            b"all_conversions_value_per_cost",
            "average_cost",
            b"average_cost",
            "average_cpc",
            b"average_cpc",
            "average_cpe",
            b"average_cpe",
            "average_cpm",
            b"average_cpm",
            "average_cpv",
            b"average_cpv",
            "average_page_views",
            b"average_page_views",
            "average_time_on_site",
            b"average_time_on_site",
            "benchmark_average_max_cpc",
            b"benchmark_average_max_cpc",
            "benchmark_ctr",
            b"benchmark_ctr",
            "bounce_rate",
            b"bounce_rate",
            "clicks",
            b"clicks",
            "combined_clicks",
            b"combined_clicks",
            "combined_clicks_per_query",
            b"combined_clicks_per_query",
            "combined_queries",
            b"combined_queries",
            "content_budget_lost_impression_share",
            b"content_budget_lost_impression_share",
            "content_impression_share",
            b"content_impression_share",
            "content_rank_lost_impression_share",
            b"content_rank_lost_impression_share",
            "conversion_last_conversion_date",
            b"conversion_last_conversion_date",
            "conversion_last_received_request_date_time",
            b"conversion_last_received_request_date_time",
            "conversions",
            b"conversions",
            "conversions_from_interactions_rate",
            b"conversions_from_interactions_rate",
            "conversions_from_interactions_value_per_interaction",
            b"conversions_from_interactions_value_per_interaction",
            "conversions_value",
            b"conversions_value",
            "conversions_value_per_cost",
            b"conversions_value_per_cost",
            "cost_micros",
            b"cost_micros",
            "cost_per_all_conversions",
            b"cost_per_all_conversions",
            "cost_per_conversion",
            b"cost_per_conversion",
            "cost_per_current_model_attributed_conversion",
            b"cost_per_current_model_attributed_conversion",
            "cross_device_conversions",
            b"cross_device_conversions",
            "ctr",
            b"ctr",
            "current_model_attributed_conversions",
            b"current_model_attributed_conversions",
            "current_model_attributed_conversions_from_interactions_rate",
            b"current_model_attributed_conversions_from_interactions_rate",
            "current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"current_model_attributed_conversions_from_interactions_value_per_interaction",
            "current_model_attributed_conversions_value",
            b"current_model_attributed_conversions_value",
            "current_model_attributed_conversions_value_per_cost",
            b"current_model_attributed_conversions_value_per_cost",
            "engagement_rate",
            b"engagement_rate",
            "engagements",
            b"engagements",
            "gmail_forwards",
            b"gmail_forwards",
            "gmail_saves",
            b"gmail_saves",
            "gmail_secondary_clicks",
            b"gmail_secondary_clicks",
            "historical_quality_score",
            b"historical_quality_score",
            "hotel_average_lead_value_micros",
            b"hotel_average_lead_value_micros",
            "hotel_eligible_impressions",
            b"hotel_eligible_impressions",
            "hotel_price_difference_percentage",
            b"hotel_price_difference_percentage",
            "impressions",
            b"impressions",
            "impressions_from_store_reach",
            b"impressions_from_store_reach",
            "interaction_rate",
            b"interaction_rate",
            "interactions",
            b"interactions",
            "invalid_click_rate",
            b"invalid_click_rate",
            "invalid_clicks",
            b"invalid_clicks",
            "message_chat_rate",
            b"message_chat_rate",
            "message_chats",
            b"message_chats",
            "message_impressions",
            b"message_impressions",
            "mobile_friendly_clicks_percentage",
            b"mobile_friendly_clicks_percentage",
            "organic_clicks",
            b"organic_clicks",
            "organic_clicks_per_query",
            b"organic_clicks_per_query",
            "organic_impressions",
            b"organic_impressions",
            "organic_impressions_per_query",
            b"organic_impressions_per_query",
            "organic_queries",
            b"organic_queries",
            "percent_new_visitors",
            b"percent_new_visitors",
            "phone_calls",
            b"phone_calls",
            "phone_impressions",
            b"phone_impressions",
            "phone_through_rate",
            b"phone_through_rate",
            "relative_ctr",
            b"relative_ctr",
            "search_absolute_top_impression_share",
            b"search_absolute_top_impression_share",
            "search_budget_lost_absolute_top_impression_share",
            b"search_budget_lost_absolute_top_impression_share",
            "search_budget_lost_impression_share",
            b"search_budget_lost_impression_share",
            "search_budget_lost_top_impression_share",
            b"search_budget_lost_top_impression_share",
            "search_click_share",
            b"search_click_share",
            "search_exact_match_impression_share",
            b"search_exact_match_impression_share",
            "search_impression_share",
            b"search_impression_share",
            "search_rank_lost_absolute_top_impression_share",
            b"search_rank_lost_absolute_top_impression_share",
            "search_rank_lost_impression_share",
            b"search_rank_lost_impression_share",
            "search_rank_lost_top_impression_share",
            b"search_rank_lost_top_impression_share",
            "search_top_impression_share",
            b"search_top_impression_share",
            "speed_score",
            b"speed_score",
            "top_impression_percentage",
            b"top_impression_percentage",
            "valid_accelerated_mobile_pages_clicks_percentage",
            b"valid_accelerated_mobile_pages_clicks_percentage",
            "value_per_all_conversions",
            b"value_per_all_conversions",
            "value_per_all_conversions_by_conversion_date",
            b"value_per_all_conversions_by_conversion_date",
            "value_per_conversion",
            b"value_per_conversion",
            "value_per_conversions_by_conversion_date",
            b"value_per_conversions_by_conversion_date",
            "value_per_current_model_attributed_conversion",
            b"value_per_current_model_attributed_conversion",
            "video_quartile_p100_rate",
            b"video_quartile_p100_rate",
            "video_quartile_p25_rate",
            b"video_quartile_p25_rate",
            "video_quartile_p50_rate",
            b"video_quartile_p50_rate",
            "video_quartile_p75_rate",
            b"video_quartile_p75_rate",
            "video_view_rate",
            b"video_view_rate",
            "video_views",
            b"video_views",
            "view_through_conversions",
            b"view_through_conversions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_absolute_top_impression_percentage",
            b"_absolute_top_impression_percentage",
            "_active_view_cpm",
            b"_active_view_cpm",
            "_active_view_ctr",
            b"_active_view_ctr",
            "_active_view_impressions",
            b"_active_view_impressions",
            "_active_view_measurability",
            b"_active_view_measurability",
            "_active_view_measurable_cost_micros",
            b"_active_view_measurable_cost_micros",
            "_active_view_measurable_impressions",
            b"_active_view_measurable_impressions",
            "_active_view_viewability",
            b"_active_view_viewability",
            "_all_conversions",
            b"_all_conversions",
            "_all_conversions_from_click_to_call",
            b"_all_conversions_from_click_to_call",
            "_all_conversions_from_directions",
            b"_all_conversions_from_directions",
            "_all_conversions_from_interactions_rate",
            b"_all_conversions_from_interactions_rate",
            "_all_conversions_from_interactions_value_per_interaction",
            b"_all_conversions_from_interactions_value_per_interaction",
            "_all_conversions_from_menu",
            b"_all_conversions_from_menu",
            "_all_conversions_from_order",
            b"_all_conversions_from_order",
            "_all_conversions_from_other_engagement",
            b"_all_conversions_from_other_engagement",
            "_all_conversions_from_store_visit",
            b"_all_conversions_from_store_visit",
            "_all_conversions_from_store_website",
            b"_all_conversions_from_store_website",
            "_all_conversions_value",
            b"_all_conversions_value",
            "_all_conversions_value_per_cost",
            b"_all_conversions_value_per_cost",
            "_average_cost",
            b"_average_cost",
            "_average_cpc",
            b"_average_cpc",
            "_average_cpe",
            b"_average_cpe",
            "_average_cpm",
            b"_average_cpm",
            "_average_cpv",
            b"_average_cpv",
            "_average_page_views",
            b"_average_page_views",
            "_average_time_on_site",
            b"_average_time_on_site",
            "_benchmark_average_max_cpc",
            b"_benchmark_average_max_cpc",
            "_benchmark_ctr",
            b"_benchmark_ctr",
            "_bounce_rate",
            b"_bounce_rate",
            "_clicks",
            b"_clicks",
            "_combined_clicks",
            b"_combined_clicks",
            "_combined_clicks_per_query",
            b"_combined_clicks_per_query",
            "_combined_queries",
            b"_combined_queries",
            "_content_budget_lost_impression_share",
            b"_content_budget_lost_impression_share",
            "_content_impression_share",
            b"_content_impression_share",
            "_content_rank_lost_impression_share",
            b"_content_rank_lost_impression_share",
            "_conversion_last_conversion_date",
            b"_conversion_last_conversion_date",
            "_conversion_last_received_request_date_time",
            b"_conversion_last_received_request_date_time",
            "_conversions",
            b"_conversions",
            "_conversions_from_interactions_rate",
            b"_conversions_from_interactions_rate",
            "_conversions_from_interactions_value_per_interaction",
            b"_conversions_from_interactions_value_per_interaction",
            "_conversions_value",
            b"_conversions_value",
            "_conversions_value_per_cost",
            b"_conversions_value_per_cost",
            "_cost_micros",
            b"_cost_micros",
            "_cost_per_all_conversions",
            b"_cost_per_all_conversions",
            "_cost_per_conversion",
            b"_cost_per_conversion",
            "_cost_per_current_model_attributed_conversion",
            b"_cost_per_current_model_attributed_conversion",
            "_cross_device_conversions",
            b"_cross_device_conversions",
            "_ctr",
            b"_ctr",
            "_current_model_attributed_conversions",
            b"_current_model_attributed_conversions",
            "_current_model_attributed_conversions_from_interactions_rate",
            b"_current_model_attributed_conversions_from_interactions_rate",
            "_current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"_current_model_attributed_conversions_from_interactions_value_per_interaction",
            "_current_model_attributed_conversions_value",
            b"_current_model_attributed_conversions_value",
            "_current_model_attributed_conversions_value_per_cost",
            b"_current_model_attributed_conversions_value_per_cost",
            "_engagement_rate",
            b"_engagement_rate",
            "_engagements",
            b"_engagements",
            "_gmail_forwards",
            b"_gmail_forwards",
            "_gmail_saves",
            b"_gmail_saves",
            "_gmail_secondary_clicks",
            b"_gmail_secondary_clicks",
            "_historical_quality_score",
            b"_historical_quality_score",
            "_hotel_average_lead_value_micros",
            b"_hotel_average_lead_value_micros",
            "_hotel_eligible_impressions",
            b"_hotel_eligible_impressions",
            "_hotel_price_difference_percentage",
            b"_hotel_price_difference_percentage",
            "_impressions",
            b"_impressions",
            "_impressions_from_store_reach",
            b"_impressions_from_store_reach",
            "_interaction_rate",
            b"_interaction_rate",
            "_interactions",
            b"_interactions",
            "_invalid_click_rate",
            b"_invalid_click_rate",
            "_invalid_clicks",
            b"_invalid_clicks",
            "_message_chat_rate",
            b"_message_chat_rate",
            "_message_chats",
            b"_message_chats",
            "_message_impressions",
            b"_message_impressions",
            "_mobile_friendly_clicks_percentage",
            b"_mobile_friendly_clicks_percentage",
            "_organic_clicks",
            b"_organic_clicks",
            "_organic_clicks_per_query",
            b"_organic_clicks_per_query",
            "_organic_impressions",
            b"_organic_impressions",
            "_organic_impressions_per_query",
            b"_organic_impressions_per_query",
            "_organic_queries",
            b"_organic_queries",
            "_percent_new_visitors",
            b"_percent_new_visitors",
            "_phone_calls",
            b"_phone_calls",
            "_phone_impressions",
            b"_phone_impressions",
            "_phone_through_rate",
            b"_phone_through_rate",
            "_relative_ctr",
            b"_relative_ctr",
            "_search_absolute_top_impression_share",
            b"_search_absolute_top_impression_share",
            "_search_budget_lost_absolute_top_impression_share",
            b"_search_budget_lost_absolute_top_impression_share",
            "_search_budget_lost_impression_share",
            b"_search_budget_lost_impression_share",
            "_search_budget_lost_top_impression_share",
            b"_search_budget_lost_top_impression_share",
            "_search_click_share",
            b"_search_click_share",
            "_search_exact_match_impression_share",
            b"_search_exact_match_impression_share",
            "_search_impression_share",
            b"_search_impression_share",
            "_search_rank_lost_absolute_top_impression_share",
            b"_search_rank_lost_absolute_top_impression_share",
            "_search_rank_lost_impression_share",
            b"_search_rank_lost_impression_share",
            "_search_rank_lost_top_impression_share",
            b"_search_rank_lost_top_impression_share",
            "_search_top_impression_share",
            b"_search_top_impression_share",
            "_speed_score",
            b"_speed_score",
            "_top_impression_percentage",
            b"_top_impression_percentage",
            "_valid_accelerated_mobile_pages_clicks_percentage",
            b"_valid_accelerated_mobile_pages_clicks_percentage",
            "_value_per_all_conversions",
            b"_value_per_all_conversions",
            "_value_per_all_conversions_by_conversion_date",
            b"_value_per_all_conversions_by_conversion_date",
            "_value_per_conversion",
            b"_value_per_conversion",
            "_value_per_conversions_by_conversion_date",
            b"_value_per_conversions_by_conversion_date",
            "_value_per_current_model_attributed_conversion",
            b"_value_per_current_model_attributed_conversion",
            "_video_quartile_p100_rate",
            b"_video_quartile_p100_rate",
            "_video_quartile_p25_rate",
            b"_video_quartile_p25_rate",
            "_video_quartile_p50_rate",
            b"_video_quartile_p50_rate",
            "_video_quartile_p75_rate",
            b"_video_quartile_p75_rate",
            "_video_view_rate",
            b"_video_view_rate",
            "_video_views",
            b"_video_views",
            "_view_through_conversions",
            b"_view_through_conversions",
            "absolute_top_impression_percentage",
            b"absolute_top_impression_percentage",
            "active_view_cpm",
            b"active_view_cpm",
            "active_view_ctr",
            b"active_view_ctr",
            "active_view_impressions",
            b"active_view_impressions",
            "active_view_measurability",
            b"active_view_measurability",
            "active_view_measurable_cost_micros",
            b"active_view_measurable_cost_micros",
            "active_view_measurable_impressions",
            b"active_view_measurable_impressions",
            "active_view_viewability",
            b"active_view_viewability",
            "all_conversions",
            b"all_conversions",
            "all_conversions_by_conversion_date",
            b"all_conversions_by_conversion_date",
            "all_conversions_from_click_to_call",
            b"all_conversions_from_click_to_call",
            "all_conversions_from_directions",
            b"all_conversions_from_directions",
            "all_conversions_from_interactions_rate",
            b"all_conversions_from_interactions_rate",
            "all_conversions_from_interactions_value_per_interaction",
            b"all_conversions_from_interactions_value_per_interaction",
            "all_conversions_from_menu",
            b"all_conversions_from_menu",
            "all_conversions_from_order",
            b"all_conversions_from_order",
            "all_conversions_from_other_engagement",
            b"all_conversions_from_other_engagement",
            "all_conversions_from_store_visit",
            b"all_conversions_from_store_visit",
            "all_conversions_from_store_website",
            b"all_conversions_from_store_website",
            "all_conversions_value",
            b"all_conversions_value",
            "all_conversions_value_by_conversion_date",
            b"all_conversions_value_by_conversion_date",
            "all_conversions_value_per_cost",
            b"all_conversions_value_per_cost",
            "average_cost",
            b"average_cost",
            "average_cpc",
            b"average_cpc",
            "average_cpe",
            b"average_cpe",
            "average_cpm",
            b"average_cpm",
            "average_cpv",
            b"average_cpv",
            "average_page_views",
            b"average_page_views",
            "average_time_on_site",
            b"average_time_on_site",
            "benchmark_average_max_cpc",
            b"benchmark_average_max_cpc",
            "benchmark_ctr",
            b"benchmark_ctr",
            "bounce_rate",
            b"bounce_rate",
            "clicks",
            b"clicks",
            "combined_clicks",
            b"combined_clicks",
            "combined_clicks_per_query",
            b"combined_clicks_per_query",
            "combined_queries",
            b"combined_queries",
            "content_budget_lost_impression_share",
            b"content_budget_lost_impression_share",
            "content_impression_share",
            b"content_impression_share",
            "content_rank_lost_impression_share",
            b"content_rank_lost_impression_share",
            "conversion_last_conversion_date",
            b"conversion_last_conversion_date",
            "conversion_last_received_request_date_time",
            b"conversion_last_received_request_date_time",
            "conversions",
            b"conversions",
            "conversions_by_conversion_date",
            b"conversions_by_conversion_date",
            "conversions_from_interactions_rate",
            b"conversions_from_interactions_rate",
            "conversions_from_interactions_value_per_interaction",
            b"conversions_from_interactions_value_per_interaction",
            "conversions_value",
            b"conversions_value",
            "conversions_value_by_conversion_date",
            b"conversions_value_by_conversion_date",
            "conversions_value_per_cost",
            b"conversions_value_per_cost",
            "cost_micros",
            b"cost_micros",
            "cost_per_all_conversions",
            b"cost_per_all_conversions",
            "cost_per_conversion",
            b"cost_per_conversion",
            "cost_per_current_model_attributed_conversion",
            b"cost_per_current_model_attributed_conversion",
            "cross_device_conversions",
            b"cross_device_conversions",
            "ctr",
            b"ctr",
            "current_model_attributed_conversions",
            b"current_model_attributed_conversions",
            "current_model_attributed_conversions_from_interactions_rate",
            b"current_model_attributed_conversions_from_interactions_rate",
            "current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"current_model_attributed_conversions_from_interactions_value_per_interaction",
            "current_model_attributed_conversions_value",
            b"current_model_attributed_conversions_value",
            "current_model_attributed_conversions_value_per_cost",
            b"current_model_attributed_conversions_value_per_cost",
            "engagement_rate",
            b"engagement_rate",
            "engagements",
            b"engagements",
            "gmail_forwards",
            b"gmail_forwards",
            "gmail_saves",
            b"gmail_saves",
            "gmail_secondary_clicks",
            b"gmail_secondary_clicks",
            "historical_creative_quality_score",
            b"historical_creative_quality_score",
            "historical_landing_page_quality_score",
            b"historical_landing_page_quality_score",
            "historical_quality_score",
            b"historical_quality_score",
            "historical_search_predicted_ctr",
            b"historical_search_predicted_ctr",
            "hotel_average_lead_value_micros",
            b"hotel_average_lead_value_micros",
            "hotel_eligible_impressions",
            b"hotel_eligible_impressions",
            "hotel_price_difference_percentage",
            b"hotel_price_difference_percentage",
            "impressions",
            b"impressions",
            "impressions_from_store_reach",
            b"impressions_from_store_reach",
            "interaction_event_types",
            b"interaction_event_types",
            "interaction_rate",
            b"interaction_rate",
            "interactions",
            b"interactions",
            "invalid_click_rate",
            b"invalid_click_rate",
            "invalid_clicks",
            b"invalid_clicks",
            "message_chat_rate",
            b"message_chat_rate",
            "message_chats",
            b"message_chats",
            "message_impressions",
            b"message_impressions",
            "mobile_friendly_clicks_percentage",
            b"mobile_friendly_clicks_percentage",
            "organic_clicks",
            b"organic_clicks",
            "organic_clicks_per_query",
            b"organic_clicks_per_query",
            "organic_impressions",
            b"organic_impressions",
            "organic_impressions_per_query",
            b"organic_impressions_per_query",
            "organic_queries",
            b"organic_queries",
            "percent_new_visitors",
            b"percent_new_visitors",
            "phone_calls",
            b"phone_calls",
            "phone_impressions",
            b"phone_impressions",
            "phone_through_rate",
            b"phone_through_rate",
            "relative_ctr",
            b"relative_ctr",
            "search_absolute_top_impression_share",
            b"search_absolute_top_impression_share",
            "search_budget_lost_absolute_top_impression_share",
            b"search_budget_lost_absolute_top_impression_share",
            "search_budget_lost_impression_share",
            b"search_budget_lost_impression_share",
            "search_budget_lost_top_impression_share",
            b"search_budget_lost_top_impression_share",
            "search_click_share",
            b"search_click_share",
            "search_exact_match_impression_share",
            b"search_exact_match_impression_share",
            "search_impression_share",
            b"search_impression_share",
            "search_rank_lost_absolute_top_impression_share",
            b"search_rank_lost_absolute_top_impression_share",
            "search_rank_lost_impression_share",
            b"search_rank_lost_impression_share",
            "search_rank_lost_top_impression_share",
            b"search_rank_lost_top_impression_share",
            "search_top_impression_share",
            b"search_top_impression_share",
            "speed_score",
            b"speed_score",
            "top_impression_percentage",
            b"top_impression_percentage",
            "valid_accelerated_mobile_pages_clicks_percentage",
            b"valid_accelerated_mobile_pages_clicks_percentage",
            "value_per_all_conversions",
            b"value_per_all_conversions",
            "value_per_all_conversions_by_conversion_date",
            b"value_per_all_conversions_by_conversion_date",
            "value_per_conversion",
            b"value_per_conversion",
            "value_per_conversions_by_conversion_date",
            b"value_per_conversions_by_conversion_date",
            "value_per_current_model_attributed_conversion",
            b"value_per_current_model_attributed_conversion",
            "video_quartile_p100_rate",
            b"video_quartile_p100_rate",
            "video_quartile_p25_rate",
            b"video_quartile_p25_rate",
            "video_quartile_p50_rate",
            b"video_quartile_p50_rate",
            "video_quartile_p75_rate",
            b"video_quartile_p75_rate",
            "video_view_rate",
            b"video_view_rate",
            "video_views",
            b"video_views",
            "view_through_conversions",
            b"view_through_conversions",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_absolute_top_impression_percentage",
            b"_absolute_top_impression_percentage",
        ],
    ) -> typing_extensions.Literal["absolute_top_impression_percentage"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_active_view_cpm", b"_active_view_cpm"],
    ) -> typing_extensions.Literal["active_view_cpm"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_active_view_ctr", b"_active_view_ctr"],
    ) -> typing_extensions.Literal["active_view_ctr"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_active_view_impressions", b"_active_view_impressions"
        ],
    ) -> typing_extensions.Literal["active_view_impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_active_view_measurability", b"_active_view_measurability"
        ],
    ) -> typing_extensions.Literal["active_view_measurability"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_active_view_measurable_cost_micros",
            b"_active_view_measurable_cost_micros",
        ],
    ) -> typing_extensions.Literal["active_view_measurable_cost_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_active_view_measurable_impressions",
            b"_active_view_measurable_impressions",
        ],
    ) -> typing_extensions.Literal["active_view_measurable_impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_active_view_viewability", b"_active_view_viewability"
        ],
    ) -> typing_extensions.Literal["active_view_viewability"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_all_conversions", b"_all_conversions"],
    ) -> typing_extensions.Literal["all_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_click_to_call",
            b"_all_conversions_from_click_to_call",
        ],
    ) -> typing_extensions.Literal["all_conversions_from_click_to_call"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_directions", b"_all_conversions_from_directions"
        ],
    ) -> typing_extensions.Literal["all_conversions_from_directions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_interactions_rate",
            b"_all_conversions_from_interactions_rate",
        ],
    ) -> typing_extensions.Literal["all_conversions_from_interactions_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_interactions_value_per_interaction",
            b"_all_conversions_from_interactions_value_per_interaction",
        ],
    ) -> typing_extensions.Literal[
        "all_conversions_from_interactions_value_per_interaction"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_menu", b"_all_conversions_from_menu"
        ],
    ) -> typing_extensions.Literal["all_conversions_from_menu"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_order", b"_all_conversions_from_order"
        ],
    ) -> typing_extensions.Literal["all_conversions_from_order"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_other_engagement",
            b"_all_conversions_from_other_engagement",
        ],
    ) -> typing_extensions.Literal["all_conversions_from_other_engagement"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_store_visit", b"_all_conversions_from_store_visit"
        ],
    ) -> typing_extensions.Literal["all_conversions_from_store_visit"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_store_website",
            b"_all_conversions_from_store_website",
        ],
    ) -> typing_extensions.Literal["all_conversions_from_store_website"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_value", b"_all_conversions_value"
        ],
    ) -> typing_extensions.Literal["all_conversions_value"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_value_per_cost", b"_all_conversions_value_per_cost"
        ],
    ) -> typing_extensions.Literal["all_conversions_value_per_cost"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_average_cost", b"_average_cost"]
    ) -> typing_extensions.Literal["average_cost"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_average_cpc", b"_average_cpc"]
    ) -> typing_extensions.Literal["average_cpc"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_average_cpe", b"_average_cpe"]
    ) -> typing_extensions.Literal["average_cpe"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_average_cpm", b"_average_cpm"]
    ) -> typing_extensions.Literal["average_cpm"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_average_cpv", b"_average_cpv"]
    ) -> typing_extensions.Literal["average_cpv"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_average_page_views", b"_average_page_views"
        ],
    ) -> typing_extensions.Literal["average_page_views"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_average_time_on_site", b"_average_time_on_site"
        ],
    ) -> typing_extensions.Literal["average_time_on_site"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_benchmark_average_max_cpc", b"_benchmark_average_max_cpc"
        ],
    ) -> typing_extensions.Literal["benchmark_average_max_cpc"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_benchmark_ctr", b"_benchmark_ctr"],
    ) -> typing_extensions.Literal["benchmark_ctr"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_bounce_rate", b"_bounce_rate"]
    ) -> typing_extensions.Literal["bounce_rate"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_clicks", b"_clicks"]
    ) -> typing_extensions.Literal["clicks"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_combined_clicks", b"_combined_clicks"],
    ) -> typing_extensions.Literal["combined_clicks"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_combined_clicks_per_query", b"_combined_clicks_per_query"
        ],
    ) -> typing_extensions.Literal["combined_clicks_per_query"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_combined_queries", b"_combined_queries"
        ],
    ) -> typing_extensions.Literal["combined_queries"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_content_budget_lost_impression_share",
            b"_content_budget_lost_impression_share",
        ],
    ) -> typing_extensions.Literal["content_budget_lost_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_content_impression_share", b"_content_impression_share"
        ],
    ) -> typing_extensions.Literal["content_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_content_rank_lost_impression_share",
            b"_content_rank_lost_impression_share",
        ],
    ) -> typing_extensions.Literal["content_rank_lost_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_last_conversion_date", b"_conversion_last_conversion_date"
        ],
    ) -> typing_extensions.Literal["conversion_last_conversion_date"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_last_received_request_date_time",
            b"_conversion_last_received_request_date_time",
        ],
    ) -> typing_extensions.Literal["conversion_last_received_request_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_conversions", b"_conversions"]
    ) -> typing_extensions.Literal["conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversions_from_interactions_rate",
            b"_conversions_from_interactions_rate",
        ],
    ) -> typing_extensions.Literal["conversions_from_interactions_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversions_from_interactions_value_per_interaction",
            b"_conversions_from_interactions_value_per_interaction",
        ],
    ) -> typing_extensions.Literal[
        "conversions_from_interactions_value_per_interaction"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversions_value", b"_conversions_value"
        ],
    ) -> typing_extensions.Literal["conversions_value"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversions_value_per_cost", b"_conversions_value_per_cost"
        ],
    ) -> typing_extensions.Literal["conversions_value_per_cost"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions.Literal["cost_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cost_per_all_conversions", b"_cost_per_all_conversions"
        ],
    ) -> typing_extensions.Literal["cost_per_all_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cost_per_conversion", b"_cost_per_conversion"
        ],
    ) -> typing_extensions.Literal["cost_per_conversion"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cost_per_current_model_attributed_conversion",
            b"_cost_per_current_model_attributed_conversion",
        ],
    ) -> typing_extensions.Literal["cost_per_current_model_attributed_conversion"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cross_device_conversions", b"_cross_device_conversions"
        ],
    ) -> typing_extensions.Literal["cross_device_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_ctr", b"_ctr"]
    ) -> typing_extensions.Literal["ctr"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_current_model_attributed_conversions",
            b"_current_model_attributed_conversions",
        ],
    ) -> typing_extensions.Literal["current_model_attributed_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_current_model_attributed_conversions_from_interactions_rate",
            b"_current_model_attributed_conversions_from_interactions_rate",
        ],
    ) -> typing_extensions.Literal[
        "current_model_attributed_conversions_from_interactions_rate"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"_current_model_attributed_conversions_from_interactions_value_per_interaction",
        ],
    ) -> typing_extensions.Literal[
        "current_model_attributed_conversions_from_interactions_value_per_interaction"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_current_model_attributed_conversions_value",
            b"_current_model_attributed_conversions_value",
        ],
    ) -> typing_extensions.Literal["current_model_attributed_conversions_value"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_current_model_attributed_conversions_value_per_cost",
            b"_current_model_attributed_conversions_value_per_cost",
        ],
    ) -> typing_extensions.Literal[
        "current_model_attributed_conversions_value_per_cost"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_engagement_rate", b"_engagement_rate"],
    ) -> typing_extensions.Literal["engagement_rate"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_engagements", b"_engagements"]
    ) -> typing_extensions.Literal["engagements"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_gmail_forwards", b"_gmail_forwards"],
    ) -> typing_extensions.Literal["gmail_forwards"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_gmail_saves", b"_gmail_saves"]
    ) -> typing_extensions.Literal["gmail_saves"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_gmail_secondary_clicks", b"_gmail_secondary_clicks"
        ],
    ) -> typing_extensions.Literal["gmail_secondary_clicks"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_historical_quality_score", b"_historical_quality_score"
        ],
    ) -> typing_extensions.Literal["historical_quality_score"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hotel_average_lead_value_micros", b"_hotel_average_lead_value_micros"
        ],
    ) -> typing_extensions.Literal["hotel_average_lead_value_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hotel_eligible_impressions", b"_hotel_eligible_impressions"
        ],
    ) -> typing_extensions.Literal["hotel_eligible_impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hotel_price_difference_percentage", b"_hotel_price_difference_percentage"
        ],
    ) -> typing_extensions.Literal["hotel_price_difference_percentage"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_impressions", b"_impressions"]
    ) -> typing_extensions.Literal["impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_impressions_from_store_reach", b"_impressions_from_store_reach"
        ],
    ) -> typing_extensions.Literal["impressions_from_store_reach"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_interaction_rate", b"_interaction_rate"
        ],
    ) -> typing_extensions.Literal["interaction_rate"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_interactions", b"_interactions"]
    ) -> typing_extensions.Literal["interactions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_invalid_click_rate", b"_invalid_click_rate"
        ],
    ) -> typing_extensions.Literal["invalid_click_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_invalid_clicks", b"_invalid_clicks"],
    ) -> typing_extensions.Literal["invalid_clicks"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_message_chat_rate", b"_message_chat_rate"
        ],
    ) -> typing_extensions.Literal["message_chat_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_message_chats", b"_message_chats"],
    ) -> typing_extensions.Literal["message_chats"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_message_impressions", b"_message_impressions"
        ],
    ) -> typing_extensions.Literal["message_impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_mobile_friendly_clicks_percentage", b"_mobile_friendly_clicks_percentage"
        ],
    ) -> typing_extensions.Literal["mobile_friendly_clicks_percentage"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_organic_clicks", b"_organic_clicks"],
    ) -> typing_extensions.Literal["organic_clicks"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_organic_clicks_per_query", b"_organic_clicks_per_query"
        ],
    ) -> typing_extensions.Literal["organic_clicks_per_query"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_organic_impressions", b"_organic_impressions"
        ],
    ) -> typing_extensions.Literal["organic_impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_organic_impressions_per_query", b"_organic_impressions_per_query"
        ],
    ) -> typing_extensions.Literal["organic_impressions_per_query"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_organic_queries", b"_organic_queries"],
    ) -> typing_extensions.Literal["organic_queries"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_percent_new_visitors", b"_percent_new_visitors"
        ],
    ) -> typing_extensions.Literal["percent_new_visitors"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_phone_calls", b"_phone_calls"]
    ) -> typing_extensions.Literal["phone_calls"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_phone_impressions", b"_phone_impressions"
        ],
    ) -> typing_extensions.Literal["phone_impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_phone_through_rate", b"_phone_through_rate"
        ],
    ) -> typing_extensions.Literal["phone_through_rate"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_relative_ctr", b"_relative_ctr"]
    ) -> typing_extensions.Literal["relative_ctr"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_absolute_top_impression_share",
            b"_search_absolute_top_impression_share",
        ],
    ) -> typing_extensions.Literal["search_absolute_top_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_budget_lost_absolute_top_impression_share",
            b"_search_budget_lost_absolute_top_impression_share",
        ],
    ) -> typing_extensions.Literal[
        "search_budget_lost_absolute_top_impression_share"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_budget_lost_impression_share",
            b"_search_budget_lost_impression_share",
        ],
    ) -> typing_extensions.Literal["search_budget_lost_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_budget_lost_top_impression_share",
            b"_search_budget_lost_top_impression_share",
        ],
    ) -> typing_extensions.Literal["search_budget_lost_top_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_click_share", b"_search_click_share"
        ],
    ) -> typing_extensions.Literal["search_click_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_exact_match_impression_share",
            b"_search_exact_match_impression_share",
        ],
    ) -> typing_extensions.Literal["search_exact_match_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_impression_share", b"_search_impression_share"
        ],
    ) -> typing_extensions.Literal["search_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_rank_lost_absolute_top_impression_share",
            b"_search_rank_lost_absolute_top_impression_share",
        ],
    ) -> typing_extensions.Literal[
        "search_rank_lost_absolute_top_impression_share"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_rank_lost_impression_share", b"_search_rank_lost_impression_share"
        ],
    ) -> typing_extensions.Literal["search_rank_lost_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_rank_lost_top_impression_share",
            b"_search_rank_lost_top_impression_share",
        ],
    ) -> typing_extensions.Literal["search_rank_lost_top_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_top_impression_share", b"_search_top_impression_share"
        ],
    ) -> typing_extensions.Literal["search_top_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_speed_score", b"_speed_score"]
    ) -> typing_extensions.Literal["speed_score"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_top_impression_percentage", b"_top_impression_percentage"
        ],
    ) -> typing_extensions.Literal["top_impression_percentage"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_valid_accelerated_mobile_pages_clicks_percentage",
            b"_valid_accelerated_mobile_pages_clicks_percentage",
        ],
    ) -> typing_extensions.Literal[
        "valid_accelerated_mobile_pages_clicks_percentage"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_value_per_all_conversions", b"_value_per_all_conversions"
        ],
    ) -> typing_extensions.Literal["value_per_all_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_value_per_all_conversions_by_conversion_date",
            b"_value_per_all_conversions_by_conversion_date",
        ],
    ) -> typing_extensions.Literal["value_per_all_conversions_by_conversion_date"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_value_per_conversion", b"_value_per_conversion"
        ],
    ) -> typing_extensions.Literal["value_per_conversion"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_value_per_conversions_by_conversion_date",
            b"_value_per_conversions_by_conversion_date",
        ],
    ) -> typing_extensions.Literal["value_per_conversions_by_conversion_date"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_value_per_current_model_attributed_conversion",
            b"_value_per_current_model_attributed_conversion",
        ],
    ) -> typing_extensions.Literal["value_per_current_model_attributed_conversion"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_video_quartile_p100_rate", b"_video_quartile_p100_rate"
        ],
    ) -> typing_extensions.Literal["video_quartile_p100_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_video_quartile_p25_rate", b"_video_quartile_p25_rate"
        ],
    ) -> typing_extensions.Literal["video_quartile_p25_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_video_quartile_p50_rate", b"_video_quartile_p50_rate"
        ],
    ) -> typing_extensions.Literal["video_quartile_p50_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_video_quartile_p75_rate", b"_video_quartile_p75_rate"
        ],
    ) -> typing_extensions.Literal["video_quartile_p75_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_video_view_rate", b"_video_view_rate"],
    ) -> typing_extensions.Literal["video_view_rate"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_video_views", b"_video_views"]
    ) -> typing_extensions.Literal["video_views"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_view_through_conversions", b"_view_through_conversions"
        ],
    ) -> typing_extensions.Literal["view_through_conversions"]: ...

global___Metrics = Metrics



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.asset_policy_pb2
import google.ads.google_ads.v6.proto.enums.asset_performance_label_pb2
import google.ads.google_ads.v6.proto.enums.served_asset_field_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdTextAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    PINNED_FIELD_FIELD_NUMBER: builtins.int
    ASSET_PERFORMANCE_LABEL_FIELD_NUMBER: builtins.int
    POLICY_SUMMARY_INFO_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    pinned_field: google.ads.google_ads.v6.proto.enums.served_asset_field_type_pb2.ServedAssetFieldTypeEnum.ServedAssetFieldType.V = (
        ...
    )
    asset_performance_label: google.ads.google_ads.v6.proto.enums.asset_performance_label_pb2.AssetPerformanceLabelEnum.AssetPerformanceLabel.V = (
        ...
    )
    @property
    def policy_summary_info(
        self,
    ) -> google.ads.google_ads.v6.proto.common.asset_policy_pb2.AdAssetPolicySummary: ...
    def __init__(
        self,
        *,
        text: typing.Text = ...,
        pinned_field: google.ads.google_ads.v6.proto.enums.served_asset_field_type_pb2.ServedAssetFieldTypeEnum.ServedAssetFieldType.V = ...,
        asset_performance_label: google.ads.google_ads.v6.proto.enums.asset_performance_label_pb2.AssetPerformanceLabelEnum.AssetPerformanceLabel.V = ...,
        policy_summary_info: typing.Optional[
            google.ads.google_ads.v6.proto.common.asset_policy_pb2.AdAssetPolicySummary
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_text",
            b"_text",
            "policy_summary_info",
            b"policy_summary_info",
            "text",
            b"text",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_text",
            b"_text",
            "asset_performance_label",
            b"asset_performance_label",
            "pinned_field",
            b"pinned_field",
            "policy_summary_info",
            b"policy_summary_info",
            "text",
            b"text",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_text", b"_text"]
    ) -> typing_extensions.Literal["text"]: ...

global___AdTextAsset = AdTextAsset

class AdImageAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ASSET_FIELD_NUMBER: builtins.int
    asset: typing.Text = ...
    def __init__(
        self,
        *,
        asset: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_asset", b"_asset"]
    ) -> typing_extensions.Literal["asset"]: ...

global___AdImageAsset = AdImageAsset

class AdVideoAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ASSET_FIELD_NUMBER: builtins.int
    asset: typing.Text = ...
    def __init__(
        self,
        *,
        asset: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_asset", b"_asset"]
    ) -> typing_extensions.Literal["asset"]: ...

global___AdVideoAsset = AdVideoAsset

class AdMediaBundleAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ASSET_FIELD_NUMBER: builtins.int
    asset: typing.Text = ...
    def __init__(
        self,
        *,
        asset: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_asset", b"_asset"]
    ) -> typing_extensions.Literal["asset"]: ...

global___AdMediaBundleAsset = AdMediaBundleAsset



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TargetCpaOptInRecommendationGoalEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _TargetCpaOptInRecommendationGoal(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            TargetCpaOptInRecommendationGoal.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(0)
        )
        UNKNOWN = (
            TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(1)
        )
        SAME_COST = (
            TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(2)
        )
        SAME_CONVERSIONS = (
            TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(3)
        )
        SAME_CPA = (
            TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(4)
        )
        CLOSEST_CPA = (
            TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(5)
        )
    class TargetCpaOptInRecommendationGoal(metaclass=_TargetCpaOptInRecommendationGoal):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = (
        TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(0)
    )
    UNKNOWN = TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(1)
    SAME_COST = TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(
        2
    )
    SAME_CONVERSIONS = (
        TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(3)
    )
    SAME_CPA = TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(
        4
    )
    CLOSEST_CPA = (
        TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(5)
    )
    def __init__(
        self,
    ) -> None: ...

global___TargetCpaOptInRecommendationGoalEnum = TargetCpaOptInRecommendationGoalEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CriterionTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CriterionType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CriterionType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CriterionTypeEnum.CriterionType.V(0)
        UNKNOWN = CriterionTypeEnum.CriterionType.V(1)
        KEYWORD = CriterionTypeEnum.CriterionType.V(2)
        PLACEMENT = CriterionTypeEnum.CriterionType.V(3)
        MOBILE_APP_CATEGORY = CriterionTypeEnum.CriterionType.V(4)
        MOBILE_APPLICATION = CriterionTypeEnum.CriterionType.V(5)
        DEVICE = CriterionTypeEnum.CriterionType.V(6)
        LOCATION = CriterionTypeEnum.CriterionType.V(7)
        LISTING_GROUP = CriterionTypeEnum.CriterionType.V(8)
        AD_SCHEDULE = CriterionTypeEnum.CriterionType.V(9)
        AGE_RANGE = CriterionTypeEnum.CriterionType.V(10)
        GENDER = CriterionTypeEnum.CriterionType.V(11)
        INCOME_RANGE = CriterionTypeEnum.CriterionType.V(12)
        PARENTAL_STATUS = CriterionTypeEnum.CriterionType.V(13)
        YOUTUBE_VIDEO = CriterionTypeEnum.CriterionType.V(14)
        YOUTUBE_CHANNEL = CriterionTypeEnum.CriterionType.V(15)
        USER_LIST = CriterionTypeEnum.CriterionType.V(16)
        PROXIMITY = CriterionTypeEnum.CriterionType.V(17)
        TOPIC = CriterionTypeEnum.CriterionType.V(18)
        LISTING_SCOPE = CriterionTypeEnum.CriterionType.V(19)
        LANGUAGE = CriterionTypeEnum.CriterionType.V(20)
        IP_BLOCK = CriterionTypeEnum.CriterionType.V(21)
        CONTENT_LABEL = CriterionTypeEnum.CriterionType.V(22)
        CARRIER = CriterionTypeEnum.CriterionType.V(23)
        USER_INTEREST = CriterionTypeEnum.CriterionType.V(24)
        WEBPAGE = CriterionTypeEnum.CriterionType.V(25)
        OPERATING_SYSTEM_VERSION = CriterionTypeEnum.CriterionType.V(26)
        APP_PAYMENT_MODEL = CriterionTypeEnum.CriterionType.V(27)
        MOBILE_DEVICE = CriterionTypeEnum.CriterionType.V(28)
        CUSTOM_AFFINITY = CriterionTypeEnum.CriterionType.V(29)
        CUSTOM_INTENT = CriterionTypeEnum.CriterionType.V(30)
        LOCATION_GROUP = CriterionTypeEnum.CriterionType.V(31)
        CUSTOM_AUDIENCE = CriterionTypeEnum.CriterionType.V(32)
        COMBINED_AUDIENCE = CriterionTypeEnum.CriterionType.V(33)
    class CriterionType(metaclass=_CriterionType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CriterionTypeEnum.CriterionType.V(0)
    UNKNOWN = CriterionTypeEnum.CriterionType.V(1)
    KEYWORD = CriterionTypeEnum.CriterionType.V(2)
    PLACEMENT = CriterionTypeEnum.CriterionType.V(3)
    MOBILE_APP_CATEGORY = CriterionTypeEnum.CriterionType.V(4)
    MOBILE_APPLICATION = CriterionTypeEnum.CriterionType.V(5)
    DEVICE = CriterionTypeEnum.CriterionType.V(6)
    LOCATION = CriterionTypeEnum.CriterionType.V(7)
    LISTING_GROUP = CriterionTypeEnum.CriterionType.V(8)
    AD_SCHEDULE = CriterionTypeEnum.CriterionType.V(9)
    AGE_RANGE = CriterionTypeEnum.CriterionType.V(10)
    GENDER = CriterionTypeEnum.CriterionType.V(11)
    INCOME_RANGE = CriterionTypeEnum.CriterionType.V(12)
    PARENTAL_STATUS = CriterionTypeEnum.CriterionType.V(13)
    YOUTUBE_VIDEO = CriterionTypeEnum.CriterionType.V(14)
    YOUTUBE_CHANNEL = CriterionTypeEnum.CriterionType.V(15)
    USER_LIST = CriterionTypeEnum.CriterionType.V(16)
    PROXIMITY = CriterionTypeEnum.CriterionType.V(17)
    TOPIC = CriterionTypeEnum.CriterionType.V(18)
    LISTING_SCOPE = CriterionTypeEnum.CriterionType.V(19)
    LANGUAGE = CriterionTypeEnum.CriterionType.V(20)
    IP_BLOCK = CriterionTypeEnum.CriterionType.V(21)
    CONTENT_LABEL = CriterionTypeEnum.CriterionType.V(22)
    CARRIER = CriterionTypeEnum.CriterionType.V(23)
    USER_INTEREST = CriterionTypeEnum.CriterionType.V(24)
    WEBPAGE = CriterionTypeEnum.CriterionType.V(25)
    OPERATING_SYSTEM_VERSION = CriterionTypeEnum.CriterionType.V(26)
    APP_PAYMENT_MODEL = CriterionTypeEnum.CriterionType.V(27)
    MOBILE_DEVICE = CriterionTypeEnum.CriterionType.V(28)
    CUSTOM_AFFINITY = CriterionTypeEnum.CriterionType.V(29)
    CUSTOM_INTENT = CriterionTypeEnum.CriterionType.V(30)
    LOCATION_GROUP = CriterionTypeEnum.CriterionType.V(31)
    CUSTOM_AUDIENCE = CriterionTypeEnum.CriterionType.V(32)
    COMBINED_AUDIENCE = CriterionTypeEnum.CriterionType.V(33)
    def __init__(
        self,
    ) -> None: ...

global___CriterionTypeEnum = CriterionTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.asset_pb2
import grpc

from .asset_service_pb2 import *

class AssetServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAsset(
        self,
        request: global___GetAssetRequest,
    ) -> google.ads.google_ads.v6.proto.resources.asset_pb2.Asset: ...
    def MutateAssets(
        self,
        request: global___MutateAssetsRequest,
    ) -> global___MutateAssetsResponse: ...

class AssetServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAsset(
        self,
        request: global___GetAssetRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.asset_pb2.Asset: ...
    @abc.abstractmethod
    def MutateAssets(
        self,
        request: global___MutateAssetsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAssetsResponse: ...

def add_AssetServiceServicer_to_server(
    servicer: AssetServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.ad_customizer_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.affiliate_location_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.app_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.call_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.callout_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.custom_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.dsa_page_feed_criterion_field_pb2
import google.ads.google_ads.v5.proto.enums.education_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.feed_mapping_criterion_type_pb2
import google.ads.google_ads.v5.proto.enums.feed_mapping_status_pb2
import google.ads.google_ads.v5.proto.enums.flight_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.hotel_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.job_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.local_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.location_extension_targeting_criterion_field_pb2
import google.ads.google_ads.v5.proto.enums.location_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.message_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.placeholder_type_pb2
import google.ads.google_ads.v5.proto.enums.price_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.promotion_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.real_estate_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.sitelink_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.structured_snippet_placeholder_field_pb2
import google.ads.google_ads.v5.proto.enums.travel_placeholder_field_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    FEED_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_MAPPINGS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PLACEHOLDER_TYPE_FIELD_NUMBER: builtins.int
    CRITERION_TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    status: google.ads.google_ads.v5.proto.enums.feed_mapping_status_pb2.FeedMappingStatusEnum.FeedMappingStatus.V = (
        ...
    )
    placeholder_type: google.ads.google_ads.v5.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V = (
        ...
    )
    criterion_type: google.ads.google_ads.v5.proto.enums.feed_mapping_criterion_type_pb2.FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V = (
        ...
    )
    @property
    def feed(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def attribute_field_mappings(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___AttributeFieldMapping
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        feed: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        attribute_field_mappings: typing.Optional[
            typing.Iterable[global___AttributeFieldMapping]
        ] = ...,
        status: google.ads.google_ads.v5.proto.enums.feed_mapping_status_pb2.FeedMappingStatusEnum.FeedMappingStatus.V = ...,
        placeholder_type: google.ads.google_ads.v5.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V = ...,
        criterion_type: google.ads.google_ads.v5.proto.enums.feed_mapping_criterion_type_pb2.FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "criterion_type",
            b"criterion_type",
            "feed",
            b"feed",
            "placeholder_type",
            b"placeholder_type",
            "target",
            b"target",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "attribute_field_mappings",
            b"attribute_field_mappings",
            "criterion_type",
            b"criterion_type",
            "feed",
            b"feed",
            "placeholder_type",
            b"placeholder_type",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "target",
            b"target",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["target", b"target"]
    ) -> typing_extensions.Literal["placeholder_type", "criterion_type"]: ...

global___FeedMapping = FeedMapping

class AttributeFieldMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FEED_ATTRIBUTE_ID_FIELD_NUMBER: builtins.int
    FIELD_ID_FIELD_NUMBER: builtins.int
    SITELINK_FIELD_FIELD_NUMBER: builtins.int
    CALL_FIELD_FIELD_NUMBER: builtins.int
    APP_FIELD_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_FIELD_NUMBER: builtins.int
    AFFILIATE_LOCATION_FIELD_FIELD_NUMBER: builtins.int
    CALLOUT_FIELD_FIELD_NUMBER: builtins.int
    STRUCTURED_SNIPPET_FIELD_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_FIELD_NUMBER: builtins.int
    PRICE_FIELD_FIELD_NUMBER: builtins.int
    PROMOTION_FIELD_FIELD_NUMBER: builtins.int
    AD_CUSTOMIZER_FIELD_FIELD_NUMBER: builtins.int
    DSA_PAGE_FEED_FIELD_FIELD_NUMBER: builtins.int
    LOCATION_EXTENSION_TARGETING_FIELD_FIELD_NUMBER: builtins.int
    EDUCATION_FIELD_FIELD_NUMBER: builtins.int
    FLIGHT_FIELD_FIELD_NUMBER: builtins.int
    CUSTOM_FIELD_FIELD_NUMBER: builtins.int
    HOTEL_FIELD_FIELD_NUMBER: builtins.int
    REAL_ESTATE_FIELD_FIELD_NUMBER: builtins.int
    TRAVEL_FIELD_FIELD_NUMBER: builtins.int
    LOCAL_FIELD_FIELD_NUMBER: builtins.int
    JOB_FIELD_FIELD_NUMBER: builtins.int
    sitelink_field: google.ads.google_ads.v5.proto.enums.sitelink_placeholder_field_pb2.SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V = (
        ...
    )
    call_field: google.ads.google_ads.v5.proto.enums.call_placeholder_field_pb2.CallPlaceholderFieldEnum.CallPlaceholderField.V = (
        ...
    )
    app_field: google.ads.google_ads.v5.proto.enums.app_placeholder_field_pb2.AppPlaceholderFieldEnum.AppPlaceholderField.V = (
        ...
    )
    location_field: google.ads.google_ads.v5.proto.enums.location_placeholder_field_pb2.LocationPlaceholderFieldEnum.LocationPlaceholderField.V = (
        ...
    )
    affiliate_location_field: google.ads.google_ads.v5.proto.enums.affiliate_location_placeholder_field_pb2.AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V = (
        ...
    )
    callout_field: google.ads.google_ads.v5.proto.enums.callout_placeholder_field_pb2.CalloutPlaceholderFieldEnum.CalloutPlaceholderField.V = (
        ...
    )
    structured_snippet_field: google.ads.google_ads.v5.proto.enums.structured_snippet_placeholder_field_pb2.StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderField.V = (
        ...
    )
    message_field: google.ads.google_ads.v5.proto.enums.message_placeholder_field_pb2.MessagePlaceholderFieldEnum.MessagePlaceholderField.V = (
        ...
    )
    price_field: google.ads.google_ads.v5.proto.enums.price_placeholder_field_pb2.PricePlaceholderFieldEnum.PricePlaceholderField.V = (
        ...
    )
    promotion_field: google.ads.google_ads.v5.proto.enums.promotion_placeholder_field_pb2.PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V = (
        ...
    )
    ad_customizer_field: google.ads.google_ads.v5.proto.enums.ad_customizer_placeholder_field_pb2.AdCustomizerPlaceholderFieldEnum.AdCustomizerPlaceholderField.V = (
        ...
    )
    dsa_page_feed_field: google.ads.google_ads.v5.proto.enums.dsa_page_feed_criterion_field_pb2.DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionField.V = (
        ...
    )
    location_extension_targeting_field: google.ads.google_ads.v5.proto.enums.location_extension_targeting_criterion_field_pb2.LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V = (
        ...
    )
    education_field: google.ads.google_ads.v5.proto.enums.education_placeholder_field_pb2.EducationPlaceholderFieldEnum.EducationPlaceholderField.V = (
        ...
    )
    flight_field: google.ads.google_ads.v5.proto.enums.flight_placeholder_field_pb2.FlightPlaceholderFieldEnum.FlightPlaceholderField.V = (
        ...
    )
    custom_field: google.ads.google_ads.v5.proto.enums.custom_placeholder_field_pb2.CustomPlaceholderFieldEnum.CustomPlaceholderField.V = (
        ...
    )
    hotel_field: google.ads.google_ads.v5.proto.enums.hotel_placeholder_field_pb2.HotelPlaceholderFieldEnum.HotelPlaceholderField.V = (
        ...
    )
    real_estate_field: google.ads.google_ads.v5.proto.enums.real_estate_placeholder_field_pb2.RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V = (
        ...
    )
    travel_field: google.ads.google_ads.v5.proto.enums.travel_placeholder_field_pb2.TravelPlaceholderFieldEnum.TravelPlaceholderField.V = (
        ...
    )
    local_field: google.ads.google_ads.v5.proto.enums.local_placeholder_field_pb2.LocalPlaceholderFieldEnum.LocalPlaceholderField.V = (
        ...
    )
    job_field: google.ads.google_ads.v5.proto.enums.job_placeholder_field_pb2.JobPlaceholderFieldEnum.JobPlaceholderField.V = (
        ...
    )
    @property
    def feed_attribute_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def field_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        feed_attribute_id: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        field_id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        sitelink_field: google.ads.google_ads.v5.proto.enums.sitelink_placeholder_field_pb2.SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField.V = ...,
        call_field: google.ads.google_ads.v5.proto.enums.call_placeholder_field_pb2.CallPlaceholderFieldEnum.CallPlaceholderField.V = ...,
        app_field: google.ads.google_ads.v5.proto.enums.app_placeholder_field_pb2.AppPlaceholderFieldEnum.AppPlaceholderField.V = ...,
        location_field: google.ads.google_ads.v5.proto.enums.location_placeholder_field_pb2.LocationPlaceholderFieldEnum.LocationPlaceholderField.V = ...,
        affiliate_location_field: google.ads.google_ads.v5.proto.enums.affiliate_location_placeholder_field_pb2.AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V = ...,
        callout_field: google.ads.google_ads.v5.proto.enums.callout_placeholder_field_pb2.CalloutPlaceholderFieldEnum.CalloutPlaceholderField.V = ...,
        structured_snippet_field: google.ads.google_ads.v5.proto.enums.structured_snippet_placeholder_field_pb2.StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderField.V = ...,
        message_field: google.ads.google_ads.v5.proto.enums.message_placeholder_field_pb2.MessagePlaceholderFieldEnum.MessagePlaceholderField.V = ...,
        price_field: google.ads.google_ads.v5.proto.enums.price_placeholder_field_pb2.PricePlaceholderFieldEnum.PricePlaceholderField.V = ...,
        promotion_field: google.ads.google_ads.v5.proto.enums.promotion_placeholder_field_pb2.PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V = ...,
        ad_customizer_field: google.ads.google_ads.v5.proto.enums.ad_customizer_placeholder_field_pb2.AdCustomizerPlaceholderFieldEnum.AdCustomizerPlaceholderField.V = ...,
        dsa_page_feed_field: google.ads.google_ads.v5.proto.enums.dsa_page_feed_criterion_field_pb2.DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionField.V = ...,
        location_extension_targeting_field: google.ads.google_ads.v5.proto.enums.location_extension_targeting_criterion_field_pb2.LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V = ...,
        education_field: google.ads.google_ads.v5.proto.enums.education_placeholder_field_pb2.EducationPlaceholderFieldEnum.EducationPlaceholderField.V = ...,
        flight_field: google.ads.google_ads.v5.proto.enums.flight_placeholder_field_pb2.FlightPlaceholderFieldEnum.FlightPlaceholderField.V = ...,
        custom_field: google.ads.google_ads.v5.proto.enums.custom_placeholder_field_pb2.CustomPlaceholderFieldEnum.CustomPlaceholderField.V = ...,
        hotel_field: google.ads.google_ads.v5.proto.enums.hotel_placeholder_field_pb2.HotelPlaceholderFieldEnum.HotelPlaceholderField.V = ...,
        real_estate_field: google.ads.google_ads.v5.proto.enums.real_estate_placeholder_field_pb2.RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V = ...,
        travel_field: google.ads.google_ads.v5.proto.enums.travel_placeholder_field_pb2.TravelPlaceholderFieldEnum.TravelPlaceholderField.V = ...,
        local_field: google.ads.google_ads.v5.proto.enums.local_placeholder_field_pb2.LocalPlaceholderFieldEnum.LocalPlaceholderField.V = ...,
        job_field: google.ads.google_ads.v5.proto.enums.job_placeholder_field_pb2.JobPlaceholderFieldEnum.JobPlaceholderField.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "ad_customizer_field",
            b"ad_customizer_field",
            "affiliate_location_field",
            b"affiliate_location_field",
            "app_field",
            b"app_field",
            "call_field",
            b"call_field",
            "callout_field",
            b"callout_field",
            "custom_field",
            b"custom_field",
            "dsa_page_feed_field",
            b"dsa_page_feed_field",
            "education_field",
            b"education_field",
            "feed_attribute_id",
            b"feed_attribute_id",
            "field",
            b"field",
            "field_id",
            b"field_id",
            "flight_field",
            b"flight_field",
            "hotel_field",
            b"hotel_field",
            "job_field",
            b"job_field",
            "local_field",
            b"local_field",
            "location_extension_targeting_field",
            b"location_extension_targeting_field",
            "location_field",
            b"location_field",
            "message_field",
            b"message_field",
            "price_field",
            b"price_field",
            "promotion_field",
            b"promotion_field",
            "real_estate_field",
            b"real_estate_field",
            "sitelink_field",
            b"sitelink_field",
            "structured_snippet_field",
            b"structured_snippet_field",
            "travel_field",
            b"travel_field",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_customizer_field",
            b"ad_customizer_field",
            "affiliate_location_field",
            b"affiliate_location_field",
            "app_field",
            b"app_field",
            "call_field",
            b"call_field",
            "callout_field",
            b"callout_field",
            "custom_field",
            b"custom_field",
            "dsa_page_feed_field",
            b"dsa_page_feed_field",
            "education_field",
            b"education_field",
            "feed_attribute_id",
            b"feed_attribute_id",
            "field",
            b"field",
            "field_id",
            b"field_id",
            "flight_field",
            b"flight_field",
            "hotel_field",
            b"hotel_field",
            "job_field",
            b"job_field",
            "local_field",
            b"local_field",
            "location_extension_targeting_field",
            b"location_extension_targeting_field",
            "location_field",
            b"location_field",
            "message_field",
            b"message_field",
            "price_field",
            b"price_field",
            "promotion_field",
            b"promotion_field",
            "real_estate_field",
            b"real_estate_field",
            "sitelink_field",
            b"sitelink_field",
            "structured_snippet_field",
            b"structured_snippet_field",
            "travel_field",
            b"travel_field",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["field", b"field"]
    ) -> typing_extensions.Literal[
        "sitelink_field",
        "call_field",
        "app_field",
        "location_field",
        "affiliate_location_field",
        "callout_field",
        "structured_snippet_field",
        "message_field",
        "price_field",
        "promotion_field",
        "ad_customizer_field",
        "dsa_page_feed_field",
        "location_extension_targeting_field",
        "education_field",
        "flight_field",
        "custom_field",
        "hotel_field",
        "real_estate_field",
        "travel_field",
        "local_field",
        "job_field",
    ]: ...

global___AttributeFieldMapping = AttributeFieldMapping



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.extension_setting_device_pb2
import google.ads.google_ads.v4.proto.enums.extension_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignExtensionSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    EXTENSION_TYPE_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    EXTENSION_FEED_ITEMS_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    extension_type: google.ads.google_ads.v4.proto.enums.extension_type_pb2.ExtensionTypeEnum.ExtensionType.V = (
        ...
    )
    device: google.ads.google_ads.v4.proto.enums.extension_setting_device_pb2.ExtensionSettingDeviceEnum.ExtensionSettingDevice.V = (
        ...
    )
    @property
    def campaign(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def extension_feed_items(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        extension_type: google.ads.google_ads.v4.proto.enums.extension_type_pb2.ExtensionTypeEnum.ExtensionType.V = ...,
        campaign: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        extension_feed_items: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        device: google.ads.google_ads.v4.proto.enums.extension_setting_device_pb2.ExtensionSettingDeviceEnum.ExtensionSettingDevice.V = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["campaign", b"campaign"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "campaign",
            b"campaign",
            "device",
            b"device",
            "extension_feed_items",
            b"extension_feed_items",
            "extension_type",
            b"extension_type",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

global___CampaignExtensionSetting = CampaignExtensionSetting



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class RealTimeBiddingSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OPT_IN_FIELD_NUMBER: builtins.int
    opt_in: builtins.bool = ...
    def __init__(
        self,
        *,
        opt_in: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_opt_in", b"_opt_in", "opt_in", b"opt_in"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_opt_in", b"_opt_in", "opt_in", b"opt_in"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_opt_in", b"_opt_in"]
    ) -> typing_extensions.Literal["opt_in"]: ...

global___RealTimeBiddingSetting = RealTimeBiddingSetting



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.keyword_plan_ad_group_keyword_pb2
import grpc

from .keyword_plan_ad_group_keyword_service_pb2 import *

class KeywordPlanAdGroupKeywordServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetKeywordPlanAdGroupKeyword(
        self,
        request: global___GetKeywordPlanAdGroupKeywordRequest,
    ) -> google.ads.google_ads.v4.proto.resources.keyword_plan_ad_group_keyword_pb2.KeywordPlanAdGroupKeyword: ...
    def MutateKeywordPlanAdGroupKeywords(
        self,
        request: global___MutateKeywordPlanAdGroupKeywordsRequest,
    ) -> global___MutateKeywordPlanAdGroupKeywordsResponse: ...

class KeywordPlanAdGroupKeywordServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetKeywordPlanAdGroupKeyword(
        self,
        request: global___GetKeywordPlanAdGroupKeywordRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.keyword_plan_ad_group_keyword_pb2.KeywordPlanAdGroupKeyword: ...
    @abc.abstractmethod
    def MutateKeywordPlanAdGroupKeywords(
        self,
        request: global___MutateKeywordPlanAdGroupKeywordsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateKeywordPlanAdGroupKeywordsResponse: ...

def add_KeywordPlanAdGroupKeywordServiceServicer_to_server(
    servicer: KeywordPlanAdGroupKeywordServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.third_party_app_analytics_link_pb2
import grpc

from .third_party_app_analytics_link_service_pb2 import *

class ThirdPartyAppAnalyticsLinkServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetThirdPartyAppAnalyticsLink(
        self,
        request: global___GetThirdPartyAppAnalyticsLinkRequest,
    ) -> google.ads.google_ads.v5.proto.resources.third_party_app_analytics_link_pb2.ThirdPartyAppAnalyticsLink: ...
    def RegenerateShareableLinkId(
        self,
        request: global___RegenerateShareableLinkIdRequest,
    ) -> global___RegenerateShareableLinkIdResponse: ...

class ThirdPartyAppAnalyticsLinkServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetThirdPartyAppAnalyticsLink(
        self,
        request: global___GetThirdPartyAppAnalyticsLinkRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.third_party_app_analytics_link_pb2.ThirdPartyAppAnalyticsLink: ...
    @abc.abstractmethod
    def RegenerateShareableLinkId(
        self,
        request: global___RegenerateShareableLinkIdRequest,
        context: grpc.ServicerContext,
    ) -> global___RegenerateShareableLinkIdResponse: ...

def add_ThirdPartyAppAnalyticsLinkServiceServicer_to_server(
    servicer: ThirdPartyAppAnalyticsLinkServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class RecommendationErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _RecommendationError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            RecommendationError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = RecommendationErrorEnum.RecommendationError.V(0)
        UNKNOWN = RecommendationErrorEnum.RecommendationError.V(1)
        BUDGET_AMOUNT_TOO_SMALL = RecommendationErrorEnum.RecommendationError.V(2)
        BUDGET_AMOUNT_TOO_LARGE = RecommendationErrorEnum.RecommendationError.V(3)
        INVALID_BUDGET_AMOUNT = RecommendationErrorEnum.RecommendationError.V(4)
        POLICY_ERROR = RecommendationErrorEnum.RecommendationError.V(5)
        INVALID_BID_AMOUNT = RecommendationErrorEnum.RecommendationError.V(6)
        ADGROUP_KEYWORD_LIMIT = RecommendationErrorEnum.RecommendationError.V(7)
        RECOMMENDATION_ALREADY_APPLIED = RecommendationErrorEnum.RecommendationError.V(
            8
        )
        RECOMMENDATION_INVALIDATED = RecommendationErrorEnum.RecommendationError.V(9)
        TOO_MANY_OPERATIONS = RecommendationErrorEnum.RecommendationError.V(10)
        NO_OPERATIONS = RecommendationErrorEnum.RecommendationError.V(11)
        DIFFERENT_TYPES_NOT_SUPPORTED = RecommendationErrorEnum.RecommendationError.V(
            12
        )
        DUPLICATE_RESOURCE_NAME = RecommendationErrorEnum.RecommendationError.V(13)
        RECOMMENDATION_ALREADY_DISMISSED = (
            RecommendationErrorEnum.RecommendationError.V(14)
        )
        INVALID_APPLY_REQUEST = RecommendationErrorEnum.RecommendationError.V(15)
    class RecommendationError(metaclass=_RecommendationError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = RecommendationErrorEnum.RecommendationError.V(0)
    UNKNOWN = RecommendationErrorEnum.RecommendationError.V(1)
    BUDGET_AMOUNT_TOO_SMALL = RecommendationErrorEnum.RecommendationError.V(2)
    BUDGET_AMOUNT_TOO_LARGE = RecommendationErrorEnum.RecommendationError.V(3)
    INVALID_BUDGET_AMOUNT = RecommendationErrorEnum.RecommendationError.V(4)
    POLICY_ERROR = RecommendationErrorEnum.RecommendationError.V(5)
    INVALID_BID_AMOUNT = RecommendationErrorEnum.RecommendationError.V(6)
    ADGROUP_KEYWORD_LIMIT = RecommendationErrorEnum.RecommendationError.V(7)
    RECOMMENDATION_ALREADY_APPLIED = RecommendationErrorEnum.RecommendationError.V(8)
    RECOMMENDATION_INVALIDATED = RecommendationErrorEnum.RecommendationError.V(9)
    TOO_MANY_OPERATIONS = RecommendationErrorEnum.RecommendationError.V(10)
    NO_OPERATIONS = RecommendationErrorEnum.RecommendationError.V(11)
    DIFFERENT_TYPES_NOT_SUPPORTED = RecommendationErrorEnum.RecommendationError.V(12)
    DUPLICATE_RESOURCE_NAME = RecommendationErrorEnum.RecommendationError.V(13)
    RECOMMENDATION_ALREADY_DISMISSED = RecommendationErrorEnum.RecommendationError.V(14)
    INVALID_APPLY_REQUEST = RecommendationErrorEnum.RecommendationError.V(15)
    def __init__(
        self,
    ) -> None: ...

global___RecommendationErrorEnum = RecommendationErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BudgetCampaignAssociationStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BudgetCampaignAssociationStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            BudgetCampaignAssociationStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(0)
        )
        UNKNOWN = BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(
            1
        )
        ENABLED = BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(
            2
        )
        REMOVED = BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(
            3
        )
    class BudgetCampaignAssociationStatus(metaclass=_BudgetCampaignAssociationStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(
        0
    )
    UNKNOWN = BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(1)
    ENABLED = BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(2)
    REMOVED = BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(3)
    def __init__(
        self,
    ) -> None: ...

global___BudgetCampaignAssociationStatusEnum = BudgetCampaignAssociationStatusEnum
